All Classes and Interfaces

Class
Description
 
 
 
 
 
Allocation-free Turbo compiler optimized for ParserNG's flat-array Matrix implementation.
 
 
 
 
 
 
 
 
 
Based on https://stackoverflow.com/questions/22695654/computing-the-nth-root-of-p-using-bigdecimals
 
 
Removes excess/redundant brackets from a tokenized mathematical expression **in-place**.
High-performance, thread-safe byte array builder with runtime endianness toggle.
 
 
 
 
 
 
 
 
Objects of this class take the output of the semantic analyzer and uses it to generate code that the derivative engine can work with.
 
 
 
 
 
Objects of this class model complex numbers.
 
 
 
 
 
 
 
Objects of this class take a data-set and simplify/reduce its complexity so that class MathExpression can easily work with it.
 
 
 
 
Objects of this class break down a scanned function into simple format to which a simple chain rule can be applied,following all the principles of differentiation.
Anything that can be mathematically differentiated..
 
High-performance, JIT-optimized Vectorized Ordinary Differential Equation (ODE) solvers.
 
 
 
Models Direction vectors.
 
Models something that can be performed.
 
 
 
 
 
 
 
 
A utility class that tracks errors and warnings during parsing operations.
 
 
 
 
 
Objects of this class seek to simplify a math expression, by taking it through a series of transformative processes.
 
 
 
 
 
 
 
 
 
 
Uses Chebyshev Polynomials to expand, evaluate, differentiate and integrate functions
High-precision Piecewise Chebyshev approximation engine.
 
 
 
 
 
 
 
 
 
 
Created by JIBOYE Oluwagbemiro Olaoluwa on 6/28/2016.
 
 
 
 
Objects of this class take a compound plot instruction, scan it into all smaller plot instructions, and then analyze each instruction to determine its type.
 
 
 
 
 
 
 
 
 
 
 
 
Objects of this class have the ability to generate a system of linear equations, randomly.
 
Examples are sort function, mode function and other methods that will return a list of numbers after acting on a number or a list of numbers
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
How to use these in your Platform When you want the derivative of a badly behaved function at a point : Map x to u using toChebyshev(x).
 
 
A DomainMap that clusters nodes tightly at BOTH the lower bound (a) and the upper bound (b).
 
 
Logarithmic map that clusters nodes near the upper bound B.
Algebraic map for the semi-infinite interval [0, infinity) Hardens against functions with "tails".
 
 
This class is NOT thread-safe.
 
 
 
 
Manages the mapping of variable names to frame slots.
Objects of this class attempt to optimize and then evaluate a math expression.
Optimized Java class to compute the depth (height) of the abstract syntax tree (AST) for a mathematical expression.
 
 
 
 
 
 
 
Is thrown whenever an illegal matrix string is found.
 
 
 
 
Guide and examples for using Turbo Mode with matrices.
Allocation-free Turbo compiler optimized for ParserNG's flat-array Matrix implementation.
 
 
Objects of this class extract a matrix from an input expression of the format: [num1,num2,...:num_i,num_i+1,....:num_j,num_j+1...: ] e.g [2,3,4:4,1,2:...] The colons represent the end of one row of values and the beginning of another.
 
Objects of this class have data storing capability and store this data in the form of Constant( Once created its value cannot be changed, neither can they be duplicated in an object of this class.) and Variable objects.
 
 
 
 
Models the methods that perform calculations in the parser.
 
 
 
 
 
 
 
 
 
Class that provides utility methods for carrying out statistical analysis on a data set consisting of real numbers.
 
 
Models a post-operand MOperator object e.g the !, inverse, square, cube operators
 
Deals with number returning statistical operators e.g sum,avg,mode e.t.c and log and antilog to any base operators
 
Objects of this class are able to perform numerical integration of a curve within a given range given that the function is continuous throughout that range.
 
Objects of this class will control the running modes of the calculator.
 
 
 
 
 
 
 
 
 
 
 
Created by Imaxinacion on 2/13/2018.
 
 
 
 
Deals with numbers of higher precision than Matrix.
 
 
 
Solves quadratic equations of the form ax² + bx + c = 0.
 
Functional interface for the method to be timed.
 
Objects of this class are used to solve for the roots of non-implicit equations.
Create a variable or use a constant for the angle Create matrix vectors for O and D Where O is the origin or point about which rotation will occur, and D are the direction coordinates(a,b,c) of the rotation rot(F,angle,origin,direction) So: rot(@(x,y,z)sin(x-y-3*z),PI,@(2,1)(2,2),@(3,1)(1,-2,3)) rot(@(x,y,z)sin(x-y-3*z),PI,@(2,1)(2,2),@(3,1)(1,-2,3))
 
 
 
 
 
 
 
 
Turbo compiler optimized for PURE SCALAR expressions.
 
 
Turbo compiler optimized for PURE SCALAR expressions.
 
 
 
 
1.
Test Class: Must be static so it doesn't try to serialize the "Serializer" class along with it.
Class that provides utility methods for carrying out statistical analysis on a data set consisting of real numbers.
Created by hp on 7/7/2016.
 
 
 
 
 
 
 
 
 
Solves the depressed cubic equation: cx^3 + ax + b = 0 Uses Cardano's method and the Trigonometric identity for Casus Irreducibilis.
 
 
 
 
 
Objects of this class supply methods that may be used for telling time and parsing String representations of time in dd:hh:mm:ss or hh:mm:ss or hh:mm formats and translating them into seconds formats.The reverse is also possible:i.e translating time in seconds into dd:hh:mm:ss format.
Created by JIBOYE Oluwagbemiro Olaoluwa on 8/5/2016.
 
 
 
High-performance root finder utilizing MethodHandles.
 
 
 
Defines the allowed return types
Models a post-operand Operator object e.g the !, inverse, square, cube operators
Models a post-operand Operator object e.g the trigonometric,logarithmic,exponential e.t.c.