Uses of Enum
com.github.gbenroscience.logic.BASE_MODE
Packages that use BASE_MODE
-
Uses of BASE_MODE in com.github.gbenroscience.logic
Subclasses with type arguments of type BASE_MODE in com.github.gbenroscience.logicMethods in com.github.gbenroscience.logic that return BASE_MODEModifier and TypeMethodDescriptionCalcLogic.getBaseMode()static BASE_MODEReturns the enum constant of this type with the specified name.static BASE_MODE[]BASE_MODE.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.github.gbenroscience.logic with parameters of type BASE_MODE