Uses of Enum
com.github.gbenroscience.logic.DRG_MODE
Packages that use DRG_MODE
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of DRG_MODE in com.github.gbenroscience.logic
Subclasses with type arguments of type DRG_MODE in com.github.gbenroscience.logicMethods in com.github.gbenroscience.logic that return DRG_MODEModifier and TypeMethodDescriptionCalcLogic.getDrgMode()static DRG_MODEReturns the enum constant of this type with the specified name.static DRG_MODE[]DRG_MODE.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.github.gbenroscience.logic with parameters of type DRG_MODE -
Uses of DRG_MODE in com.github.gbenroscience.parser
Methods in com.github.gbenroscience.parser that return DRG_MODEMethods in com.github.gbenroscience.parser with parameters of type DRG_MODE -
Uses of DRG_MODE in com.github.gbenroscience.parser.methods
Methods in com.github.gbenroscience.parser.methods that return DRG_MODEMethods in com.github.gbenroscience.parser.methods with parameters of type DRG_MODEModifier and TypeMethodDescriptionstatic MathExpression.EvalResultMethod.exec(MathExpression.EvalResult ctx, int methodId, int arity, MathExpression.EvalResult[] args, DRG_MODE DRG) static final StringDeclarations.getTrigFuncDRGVariant(String methodName, DRG_MODE drg)