Uses of Enum
com.github.gbenroscience.logic.POWER_MODE
Packages that use POWER_MODE
-
Uses of POWER_MODE in com.github.gbenroscience.logic
Subclasses with type arguments of type POWER_MODE in com.github.gbenroscience.logicMethods in com.github.gbenroscience.logic that return POWER_MODEModifier and TypeMethodDescriptionCalcLogic.getPowerMode()static POWER_MODEReturns the enum constant of this type with the specified name.static POWER_MODE[]POWER_MODE.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.github.gbenroscience.logic with parameters of type POWER_MODE