Uses of Enum
com.github.gbenroscience.logic.TRIG_MODE
Packages that use TRIG_MODE
-
Uses of TRIG_MODE in com.github.gbenroscience.logic
Subclasses with type arguments of type TRIG_MODE in com.github.gbenroscience.logicMethods in com.github.gbenroscience.logic that return TRIG_MODEModifier and TypeMethodDescriptionCalcLogic.getTrigMode()static TRIG_MODEReturns the enum constant of this type with the specified name.static TRIG_MODE[]TRIG_MODE.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.github.gbenroscience.logic with parameters of type TRIG_MODE