Uses of Enum
com.github.gbenroscience.logic.USE_MODE
Packages that use USE_MODE
-
Uses of USE_MODE in com.github.gbenroscience.logic
Subclasses with type arguments of type USE_MODE in com.github.gbenroscience.logicMethods in com.github.gbenroscience.logic that return USE_MODEModifier and TypeMethodDescriptionCalcLogic.getUseMode()static USE_MODEReturns the enum constant of this type with the specified name.static USE_MODE[]USE_MODE.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.github.gbenroscience.logic with parameters of type USE_MODE