Uses of Class
com.github.gbenroscience.math.Point
Packages that use Point
-
Uses of Point in com.github.gbenroscience.math
Methods in com.github.gbenroscience.math that return PointMethods in com.github.gbenroscience.math with parameters of type PointModifier and TypeMethodDescriptiondoublePoint.calcDistanceTo(Point pt) doubleFinds the distance between 2 Point objects lying on this Line object They must lie on this Line object, else the method will return 0;doubleLine.distanceSquared(Point p1, Point p2) Finds the square of the distance between 2 Point objects lying on this Line object They must lie on this Line object, else the method will return 0;doublePoint.findXYGrad(Point pt) doublePoint.findXZGrad(Point pt) doublePoint.findYZGrad(Point pt) static SimplePointPoint.getUtilPoint(Point point) Converts objects of this class to the normal Point object.booleanPoint.isCollinearWith(Point p1, Point p2) booleanPoint.liesBetween(Point p1, Point p2) static PointbooleanLine.passesThroughPoint(Point p1) Constructors in com.github.gbenroscience.math with parameters of type PointModifierConstructorDescriptionCreates a new Line object give the gradient and a point on the line.Creates a line between points joining: the points p1 and p2Creates a new Point object similar to this one but not referring to the same object -
Uses of Point in com.github.gbenroscience.math.graph
Methods in com.github.gbenroscience.math.graph that return PointModifier and TypeMethodDescriptionGrid.convertGraphPointToScreenPoint(Point userPoint) Say the user is about to identify plot Point p = [2,4] on the screen, He passes it in to the draw method as convertGraphPointToScreenPoint(p).Grid.convertScreenPointToGraphPointzaa(Point screenPoint) Converts a point on the screen to its equivalent point in mathematics relative to the specified origin.Grid.getLocationOfOrigin()Methods in com.github.gbenroscience.math.graph with parameters of type PointModifier and TypeMethodDescriptionGrid.convertGraphPointToScreenPoint(Point userPoint) Say the user is about to identify plot Point p = [2,4] on the screen, He passes it in to the draw method as convertGraphPointToScreenPoint(p).Grid.convertScreenPointToGraphPointzaa(Point screenPoint) Converts a point on the screen to its equivalent point in mathematics relative to the specified origin.voidGrid.setLocationOfOrigin(Point locationOfOrigin)