Uses of Class
com.github.gbenroscience.math.Size
Packages that use Size
-
Uses of Size in com.github.gbenroscience.math
Methods in com.github.gbenroscience.math that return SizeModifier and TypeMethodDescriptionSize.getScaledInstance(double scaleFactor) returns a new Size object scaled to the value given by scaleFactorSize.getScaledInstance(double scaleWidth, double scaleHeight) returns a new Size object scaled to the value given by scaleWidth and scaleHeight, both being muktipliers for the width and the height.Size.getSize()Methods in com.github.gbenroscience.math with parameters of type SizeConstructors in com.github.gbenroscience.math with parameters of type Size -
Uses of Size in com.github.gbenroscience.math.graph
Methods in com.github.gbenroscience.math.graph that return SizeMethods in com.github.gbenroscience.math.graph with parameters of type Size