Uses of Enum
com.github.gbenroscience.math.differentialcalculus.equations.DifferentialEquations.ODESolverMethod
Packages that use DifferentialEquations.ODESolverMethod
Package
Description
-
Uses of DifferentialEquations.ODESolverMethod in com.github.gbenroscience.math.differentialcalculus.equations
Subclasses with type arguments of type DifferentialEquations.ODESolverMethod in com.github.gbenroscience.math.differentialcalculus.equationsMethods in com.github.gbenroscience.math.differentialcalculus.equations that return DifferentialEquations.ODESolverMethodModifier and TypeMethodDescriptionReturns the enum constant of this type with the specified name.DifferentialEquations.ODESolverMethod.values()Returns an array containing the constants of this enum type, in the order they are declared. -
Uses of DifferentialEquations.ODESolverMethod in com.github.gbenroscience.parser.turbo.tools
Methods in com.github.gbenroscience.parser.turbo.tools with parameters of type DifferentialEquations.ODESolverMethodModifier and TypeMethodDescriptionstatic doubleScalarTurboEvaluator1.executeTurboODE(MethodHandle dy_dt, int tSlot, int ySlot, int frameSize, double t0, double y0, double tEnd, double initialStep, DifferentialEquations.ODESolverMethod method)