Uses of Package
com.github.gbenroscience.math.differentialcalculus
Packages that use com.github.gbenroscience.math.differentialcalculus
-
Classes in com.github.gbenroscience.math.differentialcalculus used by com.github.gbenroscience.math.differentialcalculusClassDescriptionObjects of this class break down a scanned function into simple format to which a simple chain rule can be applied,following all the principles of differentiation.Anything that can be mathematically differentiated..