Uses of Class
com.github.gbenroscience.math.geom.Dimension
Packages that use Dimension
-
Uses of Dimension in com.github.gbenroscience.math.geom
Methods in com.github.gbenroscience.math.geom that return DimensionModifier and TypeMethodDescriptionDimension.getScaledInstance(double scaleFactor) returns a new Size object scaled to the value given by scaleFactorDimension.getScaledInstance(double scaleWidth, double scaleHeight) returns a new Size object scaled to the value given by scaleWidth and scaleHeight, both being multipliers for the width and the height.Dimension.getSize()Methods in com.github.gbenroscience.math.geom with parameters of type DimensionConstructors in com.github.gbenroscience.math.geom with parameters of type Dimension