Uses of Class
com.github.gbenroscience.math.geom.Direction
Packages that use Direction
-
Uses of Direction in com.github.gbenroscience.math.geom
Methods in com.github.gbenroscience.math.geom that return DirectionModifier and TypeMethodDescriptionLine3D.direction()ROTOR.getDirection()The direction indices of rotation.Plane.getDirectionIndices()Methods in com.github.gbenroscience.math.geom with parameters of type DirectionModifier and TypeMethodDescriptionvoidROTOR.setDirection(Direction direction) The direction indices of rotation.voidPlane.setDirectionIndices(Direction directionIndices) Constructors in com.github.gbenroscience.math.geom with parameters of type DirectionModifierConstructorDescriptionCreates a new Line object given a point through which it passes and the direction coordinates of the Line object.Creates a Plane object given the direction indices of its normal vector (stored in a gameMath.Point object)Creates a new object of class ROTOR that can be used to rotate Point objects, Line objects, and Plane objects, Function objects and so on.Creates a new object of class ROTOR that can be used to rotate Point objects, Line objects, and Plane objects, Function objects and so on.