Uses of Class
com.github.gbenroscience.math.geom.Point
Packages that use Point
-
Uses of Point in com.github.gbenroscience.math.geom
Methods in com.github.gbenroscience.math.geom that return PointModifier and TypeMethodDescriptionstatic PointPoint.getGameMathPoint(Point p1) ROTOR.getRotorCenter()Plane.intersectionWith(Line3D line) Line.intersectionWithLine(Line line) Line3D.intersectionWithLine(Line line) static Pointstatic PointROTOR.planarXYRotate(Point p, Point cen, double angle) Method for rotating a Point object in the XY plane or in any plane parallel to the XY plane.Point.pointAtDisplacement(double horDisp, double verDisp) Point.pointAtDisplacement(Line line, double distance) static PointROTOR.transformJavaCoordsToMathCoords(Point point) Converts a point in the Java screen coordinates xy plane to one in the mathematical xy plane by rotating the point through PI radians in the direction of the yz planestatic PointROTOR.transformMathCoordsToJavaCoords(Point point) Converts a point in the mathematical xy plane to one in the Java screen coordinates xy plane by rotating the point through PI radians in the direction of the yz planeMethods in com.github.gbenroscience.math.geom with parameters of type PointModifier and TypeMethodDescriptiondoublePoint.calcDistanceTo(Point pt) booleanPlane.containsPoint(Point point) doubleFinds the distance between 2 Point objects lying on this Line object They must lie on this Line object, else the method will return 0;doubledoubleLine.distanceSquared(Point p1, Point p2) Finds the square of the distance between 2 Point objects lying on this Line object They must lie on this Line object, else the method will return 0;doubleLine3D.distanceSquared(Point p1, Point p2) doublePoint.findXYGrad(Point pt) doublePoint.findXZGrad(Point pt) doublePoint.findYZGrad(Point pt) static PointPoint.getAWTPoint(Point point) Converts objects of this class to the normal Point object.booleanPoint.isCollinearWith(Point p1, Point p2) booleanPoint.liesBetween(Point p1, Point p2) static PointbooleanLine.passesThroughPoint(Point p1) booleanLine3D.passesThroughPoint(Point p1) Ascertains that a Line3D object passes through a given Point objectstatic PointROTOR.planarXYRotate(Point p, Point cen, double angle) Method for rotating a Point object in the XY plane or in any plane parallel to the XY plane.voidLine.rotateLine(double ang, Point p) static LineROTOR.rotateLine(Line line, double ang, Point p) static PolygonROTOR.rotatePolygon(Polygon p, Point orbitalCenter, double angle) static PolygonROTOR.rotateRectangle(Rectangle rect, Point orbitalCenter, double angle) Rotates a Rectangle object.voidROTOR.setRotorCenter(Point rotorCenter) static PointROTOR.transformJavaCoordsToMathCoords(Point point) Converts a point in the Java screen coordinates xy plane to one in the mathematical xy plane by rotating the point through PI radians in the direction of the yz planestatic PointROTOR.transformMathCoordsToJavaCoords(Point point) Converts a point in the mathematical xy plane to one in the Java screen coordinates xy plane by rotating the point through PI radians in the direction of the yz planeConstructors in com.github.gbenroscience.math.geom with parameters of type PointModifierConstructorDescriptionCreates a new Line object give the gradient and a point on the line.Creates a line between points joining: the points p1 and p2Creates a new Line object given a point through which it passes and the direction coordinates of the Line object.Creates a Plane object given 3 points on it.Creates a new Point object similar to this one but not referring to the same objectCreates a new object of class ROTOR that can be used to rotate Point objects, Line objects, and Plane objects, Function objects and so on.