Package com.github.gbenroscience.math.geom


package com.github.gbenroscience.math.geom
  • Classes
    Class
    Description
     
    Models Direction vectors.
     
     
     
     
    Create a variable or use a constant for the angle Create matrix vectors for O and D Where O is the origin or point about which rotation will occur, and D are the direction coordinates(a,b,c) of the rotation rot(F,angle,origin,direction) So: rot(@(x,y,z)sin(x-y-3*z),PI,@(2,1)(2,2),@(3,1)(1,-2,3)) rot(@(x,y,z)sin(x-y-3*z),PI,@(2,1)(2,2),@(3,1)(1,-2,3))