Enum FontStyle

java.lang.Object
java.lang.Enum<FontStyle>
com.github.gbenroscience.math.graph.tools.FontStyle
All Implemented Interfaces:
Serializable, Comparable<FontStyle>, java.lang.constant.Constable

public enum FontStyle extends Enum<FontStyle>
Author:
GBEMIRO
  • Enum Constant Details

    • PLAIN

      public static final FontStyle PLAIN
    • BOLD

      public static final FontStyle BOLD
    • ITALIC

      public static final FontStyle ITALIC
    • BOLD_ITALIC

      public static final FontStyle BOLD_ITALIC
  • Method Details

    • values

      public static FontStyle[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static FontStyle valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null