Class HalfDet

java.lang.Object
com.github.gbenroscience.math.matrix.expressParser.MatrixOperator
com.github.gbenroscience.math.matrix.expressParser.HalfDet

public class HalfDet extends MatrixOperator
Author:
JIBOYE Oluwagbemiro Olaoluwa
  • Constructor Details

  • Method Details

    • setIndex

      public void setIndex(int index)
    • getIndex

      public int getIndex()
    • setComplement

      public void setComplement(HalfDet complement)
    • getComplement

      public HalfDet getComplement()
    • getComplementIndex

      public static int getComplementIndex(boolean isleftHalf, int start, ArrayList<String> scan)
      Parameters:
      isleftHalf - A boolean condition that is true if the object (whose complement we seek) itself is the opening half of the determinant brace...i.e the one to the left. If false, then it is the one to the right...i.e the one to the right.
      start - The index of the HalfDet object whose complement we seek.
      scan - The ArrayList that this object resides in.
      Returns:
      the index where the complement is to be found in the ArrayList object.