Class MBinaryOperator
java.lang.Object
com.github.gbenroscience.parser.Operator
com.github.gbenroscience.math.matrix.expressParser.MOperator
com.github.gbenroscience.math.matrix.expressParser.MBinaryOperator
- All Implemented Interfaces:
Validatable
- Direct Known Subclasses:
MAdditionOperator
- Author:
- GBEMIRO
-
Field Summary
Fields inherited from class com.github.gbenroscience.math.matrix.expressParser.MOperator
COL_JOIN, DET, DET_BRACE, INV, operators, ROW_JOIN, TRI_MATRIX, UNITFields inherited from class com.github.gbenroscience.parser.Operator
AND, ASSIGN, AT, CLOSE_CIRC_BRAC, CLOSE_SQUARE_BRAC, COLON, COMBINATION, COMMA, CONST, CUBE, CUBE_ROOT, DIVIDE, EN_DASH, EQUALS, EXIT, FACTORIAL, GREATER_OR_EQUALS, GREATER_THAN, INVERSE, LESS_OR_EQUALS, LESS_THAN, MINUS, MULTIPLY, name, OPEN_CIRC_BRAC, OPEN_SQUARE_BRAC, OR, PERMUTATION, PLUS, POWER, REMAINDER, ROOT, SEMI_COLON, SPACE, SQUARE, STORE -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class com.github.gbenroscience.math.matrix.expressParser.MOperator
getName, getPrecedence, isAssignmentOperator, isBinaryOperator, isBracket, isClosingBrace, isClosingBracket, isColJoin, isColon, isCube, isDet, isDetHalfSymbol, isInverse, isMul, isOpeningBrace, isOpeningBracket, isOperatorString, isPlusOrMinus, isPower, isRowJoin, isSquare, isTri, isUnaryPostOperator, isUnaryPreOperator, isUnit, setName, validateAllMethods inherited from class com.github.gbenroscience.parser.Operator
isAtOperator, isComma, isConstantStoreCommand, isCubeRoot, isEqualsOperator, isExitCommand, isFactorial, isGreaterOrEqualsOperator, isGreaterThanOperator, isLessThanOperator, isLessThanOrEqualsOperator, isLogicOperator, isMulOrDiv, isMulOrDivOrRemOrPermOrCombOrPow, isPermOrComb, isRemainder, isSemiColon, isSquareRoot, isStoreCommand, validateAll
-
Constructor Details
-
MBinaryOperator
-
-
Method Details
-
getPrecedence
- Returns:
- the precedence of this operator
-
setIndex
-
getIndex
public int getIndex()- Returns:
- the index of this operator in the scanned Function that it belongs to.
-
validate
- Specified by:
validatein interfaceValidatable- Parameters:
scan- the scanner tokens object that this MBinaryOperator object exists in. validates the grammatical usage of this operator (by leaving the correctFunction attribute of the function object un-modified) if the usage of this operator in its immediate environment i.e to its left and right is correct.
-