Uses of Class
com.github.gbenroscience.math.matrix.expressParser.MBracket
Packages that use MBracket
-
Uses of MBracket in com.github.gbenroscience.math.matrix.expressParser
Methods in com.github.gbenroscience.math.matrix.expressParser that return MBracketModifier and TypeMethodDescriptionMBracket.createTwinBracket()non-static version of the above method.static MBracketMBracket.createTwinBracket(MBracket brac) Used to create similar objects that are not equal The object created by this class is similar to the parameter because it contains the same data as the parameter.MBracket.getComplement()Methods in com.github.gbenroscience.math.matrix.expressParser with parameters of type MBracketModifier and TypeMethodDescriptionstatic MBracketMBracket.createTwinBracket(MBracket brac) Used to create similar objects that are not equal The object created by this class is similar to the parameter because it contains the same data as the parameter.booleanbooleanMBracket.isComplement(MBracket brac) checks if the MBracket object argument below is the sane as the complement to this MBracket object.voidMBracket.setComplement(MBracket complement) Method parameters in com.github.gbenroscience.math.matrix.expressParser with type arguments of type MBracketModifier and TypeMethodDescriptionintMBracket.getNumberOfInternalBrackets(ArrayList<MBracket> brac)