Uses of Class
com.github.gbenroscience.math.matrix.expressParser.Matrix
Packages that use Matrix
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Matrix in com.github.gbenroscience.math.matrix.equationParser
Methods in com.github.gbenroscience.math.matrix.equationParser that return Matrix -
Uses of Matrix in com.github.gbenroscience.math.matrix.expressParser
Methods in com.github.gbenroscience.math.matrix.expressParser that return MatrixModifier and TypeMethodDescriptionMatrix.adjoint()static MatrixMatrix.columnJoin(Matrix mat1, Matrix mat2) Place the first Matrix object side by side with the second one passed as argument to this method.Matrix.getCofactorMatrix()Matrix.getColumnMatrix(int column) Matrix.getEigenVectorMatrix()Constructs the Eigenvector Matrix (V) internally from the original Matrix, internally generating the eigenvalues and then computing the eigenvector matrix from them.Matrix.getEigenVectorMatrix(double[] eigenvalues) Overload of getEigenVectorMatrix() that accepts an array of eigenvalues and constructs the full eigenvector matrix Constructs the Eigenvector Matrix (V) from a given array of eigenvalues.MatrixValueParser.getMatrix()MatrixVariable.getMatrix()Matrix.getRowMatrix(int row) Matrix.inverse()Row reduction technique used to compute the inverse of the matrix.Matrix.minor(int i, int j) static MatrixThe operation of matrix multiplication.Matrix.oldInverse()Computes the inverse of this Matrix object.static Matrixstatic MatrixMatrix.reduceToRowEchelonMatrix()Matrix.reduceToTriangularMatrix()static MatrixPlace the first Matrix object side by side with the second one passed as argument to this method.Matrix.scalarDivide(double scalar) Matrix.scalarMultiply(double scalar) Matrix.solveEquation()Used to solve a system of simultaneous equations placed in this Matrix object.static MatrixMatrix.solveEquation(Matrix matrix) Used to solve a system of simultaneous equations placed in the Matrix object.Matrix.transpose()Matrix.unitMatrix()static MatrixMatrix.unitMatrix(int rowSize, int colSize) static MatrixMatrix.unitMatrix(Matrix mat) static final MatrixMatrix.vectorToMatrix(double[] vector) Convert a vector to a MatrixMethods in com.github.gbenroscience.math.matrix.expressParser with parameters of type MatrixModifier and TypeMethodDescriptionstatic MatrixMatrix.columnJoin(Matrix mat1, Matrix mat2) Place the first Matrix object side by side with the second one passed as argument to this method.booleanstatic final Stringvoidstatic MatrixThe operation of matrix multiplication.static Matrixstatic Matrixstatic MatrixPlace the first Matrix object side by side with the second one passed as argument to this method.voidstatic MatrixMatrix.solveEquation(Matrix matrix) Used to solve a system of simultaneous equations placed in the Matrix object.static MatrixMatrix.unitMatrix(Matrix mat) Constructors in com.github.gbenroscience.math.matrix.expressParser with parameters of type Matrix -
Uses of Matrix in com.github.gbenroscience.parser
Fields in com.github.gbenroscience.parser declared as MatrixMethods in com.github.gbenroscience.parser that return MatrixModifier and TypeMethodDescriptionSet.addMatrix()The list must have been originally supplied: matrix_add(A,B) {where A and B are matrices} It adds them out and returns the result as a list.Set.adjoint()The list must have been originally supplied: adjoint(A) {where A is a Matrix} It finds the adjoint of A and returns the result as a list.Function.calcInverse()Set.cofactorMatrix()The list must have been originally supplied: adjoint(A) {where A is a Matrix} It finds the adjoint of A and returns the result as a list.Set.divideMatrix()The list must have been originally supplied: matrix_div(A,B) {where A and B are matrices} or matrix_div(A,k) {where A is a matrix and k is a scalar} It divides them out and returns the result as a list.Set.echelon()The input list is such that: The first 2 entries specify the number of rows and columns.Set.editMatrix()The list must have been originally supplied: transpose(A) {where A is a Matrix} It transposes A and returns the result as a list.Set.eigenValues()Set.eigenVectors()*A = VɅV-¹Check: Is ||A*v - lambda*v|| close to zero? double[] Av = matrixMultiply(A, v); double[] lv = scalarMultiply(lambda, v); double residual = computeNorm(subtract(Av, lv)); if (residual > 1e-9) { // This eigenvalue/vector pair might be inaccurate } The list must have been originally supplied: eigvec(A) {where A is a Matrix} It finds the eigenvalues of A and returns the result as a list.Function.getMatrix()Set.invert()static MatrixFunction.listToMatrix(List<String> data) Set.listToMatrix()The input list is such that: The first 2 entries specify the number of rows and columns.Set.multiplyMatrix()The list must have been originally supplied: matrix_mul(A,B) {where A and B are matrices} or matrix_mul(A,k) {where A is a matrix and k is a scalar} It multiplies them out and returns the result as a list.Set.powerMatrix()The list must have been originally supplied: matrix_pow(A,n) {where A is a Matrix and n is an integer.Function.reduceToEchelon()Set.solveSystem()The input list must be an n rows by n+1 columns matrixSet.subtractMatrix()The list must have been originally supplied: matrix_sub(A,B) {where A and B are matrices} It subtracts them out and returns the result as a list.Set.transpose()The list must have been originally supplied: transpose(A) {where A is a Matrix} It transposes A and returns the result as a list.Function.triangularMatrix()Set.triMatrix()The input list is such that: The first 2 entries specify the number of rows and columns.Methods in com.github.gbenroscience.parser with parameters of type MatrixModifier and TypeMethodDescriptionstatic StringFunction.matrixToCommaList(Matrix mat) Function.matrixToList(Matrix mat) The input list is such that: The first 2 entries specify the number of rows and columns.voidstatic StringFunction.storeAnonymousMatrixFunction(Matrix matrix) Constructors in com.github.gbenroscience.parser with parameters of type Matrix -
Uses of Matrix in com.github.gbenroscience.parser.turbo.tools
Fields in com.github.gbenroscience.parser.turbo.tools declared as MatrixMethods in com.github.gbenroscience.parser.turbo.tools that return MatrixModifier and TypeMethodDescriptiondefault MatrixFastCompositeExpression.applyMatrix(double[] variables) Convenience method for matrix extraction.static MatrixMatrixTurboEvaluator.EigenProvider.getEigenvalues(int n, double[] data) EigenEngineTurbo.getEigenvectors(int n, double[] matrixData) static MatrixMatrixTurboEvaluator.EigenProvider.getEigenvectors(int n, double[] data) MatrixTurboEvaluator.ResultCache.getMatrixBuffer(int rows, int cols) MatrixTurboEvaluator.ResultCache.getSecondaryBuffer(int rows, int cols) MatrixTurboEvaluator.ResultCache.getTertiaryBuffer(int rows, int cols)