Uses of Class
com.github.gbenroscience.math.matrix.expressParser.MatrixOld
Packages that use MatrixOld
-
Uses of MatrixOld in com.github.gbenroscience.math.matrix.expressParser
Methods in com.github.gbenroscience.math.matrix.expressParser that return MatrixOldModifier and TypeMethodDescriptionMatrixOld.adjoint()static MatrixOldMatrixOld.columnJoin(MatrixOld mat1, MatrixOld mat2) Place the first MatrixOld object side by side with the second one passed as argument to this method.MatrixOld.getCofactorMatrixOld()MatrixOld.getColumnMatrixOld(int column) MatrixOld.getRowMatrixOld(int row) MatrixOld.inverse()Row reduction technique used to compute the inverse of the matrix.MatrixOld.minor(int i, int j) static MatrixOldThe operation of matrix multiplication.MatrixOld.oldInverse()Computes the inverse of this MatrixOld object.static MatrixOldstatic MatrixOldMatrixOld.reduceToRowEchelonMatrixOld()MatrixOld.reduceToTriangularMatrixOld()static MatrixOldPlace the first MatrixOld object side by side with the second one passed as argument to this method.MatrixOld.scalarDivide(double scalar) MatrixOld.scalarMultiply(double scalar) MatrixOld.solveEquation()Used to solve a system of simultaneous equations placed in this MatrixOld object.static MatrixOldMatrixOld.solveEquation(MatrixOld matrix) Used to solve a system of simultaneous equations placed in the MatrixOld object.MatrixOld.transpose()MatrixOld.unitMatrixOld()static MatrixOldMatrixOld.unitMatrixOld(int rowSize, int colSize) static MatrixOldMatrixOld.unitMatrixOld(MatrixOld mat) Methods in com.github.gbenroscience.math.matrix.expressParser with parameters of type MatrixOldModifier and TypeMethodDescriptionstatic MatrixOldMatrixOld.columnJoin(MatrixOld mat1, MatrixOld mat2) Place the first MatrixOld object side by side with the second one passed as argument to this method.static final StringMatrixOld.findCharacteristicPolynomialForEigenValues(MatrixOld m) voidstatic MatrixOldThe operation of matrix multiplication.static MatrixOldstatic MatrixOldstatic MatrixOldPlace the first MatrixOld object side by side with the second one passed as argument to this method.static MatrixOldMatrixOld.solveEquation(MatrixOld matrix) Used to solve a system of simultaneous equations placed in the MatrixOld object.static MatrixOldMatrixOld.unitMatrixOld(MatrixOld mat) Constructors in com.github.gbenroscience.math.matrix.expressParser with parameters of type MatrixOld