Uses of Class
com.github.gbenroscience.math.matrix.expressParser.MatrixVariable
Packages that use MatrixVariable
-
Uses of MatrixVariable in com.github.gbenroscience.math.matrix
Methods in com.github.gbenroscience.math.matrix that return MatrixVariableMethods in com.github.gbenroscience.math.matrix that return types with arguments of type MatrixVariableMethod parameters in com.github.gbenroscience.math.matrix with type arguments of type MatrixVariableModifier and TypeMethodDescriptionvoidMatrixVariableManager.setVarStore(ArrayList<MatrixVariable> varStore) set the storage to the new one specified by the parameter of this method