Uses of Package
com.github.gbenroscience.math.matrix
Packages that use com.github.gbenroscience.math.matrix
-
Classes in com.github.gbenroscience.math.matrix used by com.github.gbenroscience.math.matrix.expressParserClassDescriptionObjects of this class have data storing capability and store this data in the form of Constant( Once created its value cannot be changed, neither can they be duplicated in an object of this class.) and Variable objects.