Class FunctionExpander.ChebyshevForest1

java.lang.Object
com.github.gbenroscience.math.numericalmethods.FunctionExpander.ChebyshevForest1
Enclosing class:
FunctionExpander

public static final class FunctionExpander.ChebyshevForest1 extends Object
Author:
GBEMIRO
  • Constructor Details

    • ChebyshevForest1

      public ChebyshevForest1()
  • Method Details

    • build

      public void build(MethodHandle function, double a, double b) throws Throwable
      Throws:
      Throwable
    • build

      public void build(Function function, double a, double b) throws Throwable
      Throws:
      Throwable
    • integrate

      public double integrate()
      The global integral is simply the sum of the integrals of all segments.
    • derivative

      public double derivative(double x)
      To find the derivative at x, we find the specific segment containing x.
    • evaluate

      public double evaluate(double x)