Uses of Enum
com.github.gbenroscience.math.numericalmethods.ComplexityAnalyst.Strategy
Packages that use ComplexityAnalyst.Strategy
-
Uses of ComplexityAnalyst.Strategy in com.github.gbenroscience.math.numericalmethods
Subclasses with type arguments of type ComplexityAnalyst.Strategy in com.github.gbenroscience.math.numericalmethodsMethods in com.github.gbenroscience.math.numericalmethods that return ComplexityAnalyst.StrategyModifier and TypeMethodDescriptionstatic ComplexityAnalyst.StrategyComplexityAnalyst.selectStrategy(MathExpression expr) static ComplexityAnalyst.StrategyReturns the enum constant of this type with the specified name.static ComplexityAnalyst.Strategy[]ComplexityAnalyst.Strategy.values()Returns an array containing the constants of this enum type, in the order they are declared.