Package com.github.gbenroscience.math.numericalmethods
package com.github.gbenroscience.math.numericalmethods
-
ClassDescriptionUses Chebyshev Polynomials to expand, evaluate, differentiate and integrate functionsHigh-precision Piecewise Chebyshev approximation engine.How to use these in your Platform When you want the derivative of a badly behaved function at a point : Map x to u using toChebyshev(x).A DomainMap that clusters nodes tightly at BOTH the lower bound (a) and the upper bound (b).Logarithmic map that clusters nodes near the upper bound B.Algebraic map for the semi-infinite interval [0, infinity) Hardens against functions with "tails".Objects of this class are able to perform numerical integration of a curve within a given range given that the function is continuous throughout that range.Objects of this class are used to solve for the roots of non-implicit equations.High-performance root finder utilizing MethodHandles.