Class BaseNFunction
java.lang.Object
com.github.gbenroscience.parser.MathExpression
com.github.gbenroscience.math.otherBaseParser.BaseNFunction
- All Implemented Interfaces:
Savable,Solvable,Serializable
- Author:
- JIBOYE Oluwagbemiro Olaoluwa
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.gbenroscience.parser.MathExpression
MathExpression.EvalResult, MathExpression.Pair<K,V>, MathExpression.Slot, MathExpression.Token, MathExpression.VariableRegistry -
Field Summary
Fields inherited from class com.github.gbenroscience.parser.MathExpression
correctFunction, hasListReturningOperators, noOfListReturningOperators, parser_Result, scanner, SYNTAX_ERROR -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionintstatic voidvoidsetBaseOfOperation(int baseOfOperation) solve()Methods inherited from class com.github.gbenroscience.parser.MathExpression
checkErrorLogs, clone, compileTurbo, copy, copyErrorLogTo, createNewVariableRegistry, getCachedPostfix, getCompiledTurbo, getDRG, getExecutionFrame, getExpression, getNextResult, getRegistry, getReturnObjectName, getReturnType, getScanner, getSlotItems, getSlots, getTreeStats, getValue, getVariable, getVariableManager, getVariables, getVariablesNames, hasVariable, isAutoInitOn, isCorrectFunction, isHasListReturningOperators, isOptimizable, isScannedAndOptimized, isTurboCompiled, isVariableHandlerOnly, isWillFoldConstants, main1, parse, readErrorLog, serialize, setAutoInitOn, setCorrectFunction, setDRG, setDRG, setExpression, setHasListReturningOperators, setNoOfListReturningOperators, setOptimizable, setReturnType, setValue, setVariableHandlerOnly, setVariableManager, setVariableValuesInFunction, setWillFoldConstants, solve, solve, solveGeneric, solveGeneric, updateArgs, updateSlot
-
Constructor Details
-
BaseNFunction
- Parameters:
input- The function to be evaluated. The general format contains variable and constant declarations for variables and constants that are not yet initialized,assignment expressions for those that have been initialized and then an expression to evaluate. e.g. var x =-12; var y =x+1/12; const x1,x2,x3=10; var z =sin(3x-1)+2.98cos(4x);cos(3x+12); The last expression is function to be evaluated and it is always without any equals sign and may or may not end with a semicolon.baseOfOperation- The number base that objects of this class will use in computations.
-
-
Method Details
-
setBaseOfOperation
public void setBaseOfOperation(int baseOfOperation) -
getBaseOfOperation
public int getBaseOfOperation() -
solve
- Specified by:
solvein interfaceSolvable- Overrides:
solvein classMathExpression
-
main
-