Class QuadraticExpressionParser
java.lang.Object
com.github.gbenroscience.math.quadratic.QuadraticExpressionParser
- Author:
- JIBOYE Oluwagbemiro Olaoluwa
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidWhen the situation x+2y+z=9; is met, this method will convert it into 1.0x+2y+z=9;voidThis method initializes the coefficients field with the coefficient of Xsquared at index 0 the coefficient of X at index 1 the coefficient of the constant term at index 2voidremoves white space from the ArrayListbooleanisValid()static voidvoidturns the Xsquare into a single variable.voidvoidsetExpression(String expression) voidsetScanner(ArrayList<String> scanner) voidsetValid(boolean valid) voidChecks the character set of this parser.voidvoidChecks the left and right of a number to see if the appropriate items are the ones there.voidChecks if the variables are properly arranged wrt other tokens.
-
Constructor Details
-
QuadraticExpressionParser
-
-
Method Details
-
getCoefficients
-
freeWhiteSpaces
public void freeWhiteSpaces()removes white space from the ArrayList -
setValid
public void setValid(boolean valid) -
isValid
public boolean isValid() -
setScanner
-
getScanner
-
setExpression
-
getExpression
-
appendOneToStartOfFreeVariables
public void appendOneToStartOfFreeVariables()When the situation x+2y+z=9; is met, this method will convert it into 1.0x+2y+z=9; -
validateEqualsSymbol
public void validateEqualsSymbol() -
validateChars
public void validateChars()Checks the character set of this parser. -
validateVars
public void validateVars()Checks if the variables are properly arranged wrt other tokens. -
validateNumbers
public void validateNumbers()Checks the left and right of a number to see if the appropriate items are the ones there. It is a syntax error if an invalid item is found there -
recognizeNegativesAndPositives
public void recognizeNegativesAndPositives() -
recognizeCompoundVariables
public void recognizeCompoundVariables()turns the Xsquare into a single variable. -
getUnknown
- Returns:
- the name of the unknown.
-
doArithmetic
public void doArithmetic()This method initializes the coefficients field with the coefficient of Xsquared at index 0 the coefficient of X at index 1 the coefficient of the constant term at index 2 -
interpretedSystem
- Returns:
- the reduced form of the system in the form Ax²+Bx+C=0;
-
main
-