Class MathExpression.VariableRegistry
java.lang.Object
com.github.gbenroscience.parser.MathExpression.VariableRegistry
- All Implemented Interfaces:
Savable,Serializable
- Enclosing class:
MathExpression
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected MathExpression.VariableRegistryclone()intReturns the slot index for a variable name.booleanhasVariable(String name) voidreset()intsize()Returns the total number of slots required for the execution frame.
-
Constructor Details
-
VariableRegistry
public VariableRegistry()
-
-
Method Details
-
getSlot
Returns the slot index for a variable name. If the name is new, it assigns a new slot.- Parameters:
name- The name of the Variable
-
hasVariable
-
size
public int size()Returns the total number of slots required for the execution frame. -
reset
public void reset() -
clone
-