JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
PLUS
MINUS
DIVIDE
MULTIPLY
REMAINDER
POWER
ROOT
CUBE_ROOT
SQUARE
CUBE
INVERSE
LESS_THAN
GREATER_THAN
LESS_OR_EQUALS
GREATER_OR_EQUALS
EQUALS
ASSIGN
AND
OR
OPEN_CIRC_BRAC
CLOSE_CIRC_BRAC
OPEN_SQUARE_BRAC
CLOSE_SQUARE_BRAC
COMMA
COLON
SEMI_COLON
FACTORIAL
PERMUTATION
COMBINATION
CONST
STORE
EXIT
EN_DASH
SPACE
AT
Method Details
values()
valueOf(String)
getSymbol()
isOperatorString(String)
fromString(String)
Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
Handy method to get the actual Enum from a string
static boolean
Replaces your old isOperatorString(String op)
Constant time lookup O(1)
Returns the enum constant of this type with the specified name.
Returns an array containing the constants of this enum type, in
the order they are declared.
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf