Enum ParserResult

java.lang.Object
java.lang.Enum<ParserResult>
com.github.gbenroscience.parser.ParserResult
All Implemented Interfaces:
Serializable, Comparable<ParserResult>, java.lang.constant.Constable

public enum ParserResult extends Enum<ParserResult>
  • Enum Constant Details

    • SYNTAX_ERROR

      public static final ParserResult SYNTAX_ERROR
    • INVALID_FUNCTION

      public static final ParserResult INVALID_FUNCTION
    • INCOMPLETE_PARAMS

      public static final ParserResult INCOMPLETE_PARAMS
    • PARENTHESES_ERROR

      public static final ParserResult PARENTHESES_ERROR
    • NULL_ERROR

      public static final ParserResult NULL_ERROR
    • STRANGE_INPUT

      public static final ParserResult STRANGE_INPUT
    • UNDEFINED_ARG

      public static final ParserResult UNDEFINED_ARG
    • VALID

      public static final ParserResult VALID
  • Method Details

    • values

      public static ParserResult[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static ParserResult valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null