Uses of Class
com.github.gbenroscience.parser.Bracket
Packages that use Bracket
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Bracket in com.github.gbenroscience.math.differentialcalculus
Methods in com.github.gbenroscience.math.differentialcalculus that return Bracket -
Uses of Bracket in com.github.gbenroscience.parser
Methods in com.github.gbenroscience.parser that return BracketModifier and TypeMethodDescriptionBracket.createTwinBracket()non-static version of the above method.static BracketBracket.createTwinBracket(Bracket brac) Used to create similar objects that are not equal The object created by this class is similar to the parameter because it contains the same data as the parameter.ListReturningStatsMethod.getCloseBracket()Bracket.getComplement()ListReturningStatsMethod.getOpenBracket()Methods in com.github.gbenroscience.parser with parameters of type BracketModifier and TypeMethodDescriptionstatic BracketBracket.createTwinBracket(Bracket brac) Used to create similar objects that are not equal The object created by this class is similar to the parameter because it contains the same data as the parameter.booleanbooleanbooleanBracket.isComplement(Bracket brac) checks if the Bracket object argument below is the sane as the complement to this Bracket object.voidListReturningStatsMethod.setCloseBracket(Bracket closeBracket) voidBracket.setComplement(Bracket complement) voidListReturningStatsMethod.setOpenBracket(Bracket openBracket) Method parameters in com.github.gbenroscience.parser with type arguments of type BracketModifier and TypeMethodDescriptionintBracket.getNumberOfInternalBrackets(ArrayList<Bracket> brac) intGenericBracket.getNumberOfInternalBrackets(ArrayList<Bracket> brac)