Uses of Class
com.github.gbenroscience.parser.Function
Packages that use Function
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Function in com.github.gbenroscience.math.differentialcalculus
Methods in com.github.gbenroscience.math.differentialcalculus that return FunctionMethods in com.github.gbenroscience.math.differentialcalculus with parameters of type FunctionModifier and TypeMethodDescriptionstatic doublestatic MathExpression.EvalResultstatic MathExpression.EvalResult -
Uses of Function in com.github.gbenroscience.math.numericalmethods
Methods in com.github.gbenroscience.math.numericalmethods that return FunctionModifier and TypeMethodDescriptionNumericalDerivative.getFunction()NumericalIntegral.getFunction()RootFinder.getFunction()NumericalDerivative.Parser.parseDerivativeCommand(String expression) Methods in com.github.gbenroscience.math.numericalmethods with parameters of type FunctionModifier and TypeMethodDescriptionMappedExpander.autoSelectMap(Function f, double a, double b) Detection heuristicstatic doublevoidvoidstatic doublestatic doublestatic doublestatic doubleIntegration.gaussQuad(MethodHandle targetHandle, int varIndex, Function intFunc, double lowerLimit, double upperLimit, int glPoints) doubledoubleCompute definite integral of f from a to b.doubleMappedExpander.integrateAdaptive(Function f, MappedExpander.DomainMap map, double tol, int depth) voidIntegration.setFunction(Function intFunc) voidNumericalDerivative.setFunction(Function function) voidNumericalIntegral.setFunction(Function function) final voidRootFinder.setFunction(Function function) static doubleIntegration.trapezium(Function intFunc, double lowerLimit, double upperLimit, double accuracy, int maxIntervals) static doubleConstructors in com.github.gbenroscience.math.numericalmethods with parameters of type FunctionModifierConstructorDescriptionFunctionExpander(Function function, double lower, double upper, double tolerance) FunctionExpander(Function function, double lower, double upper, int degree) Integration(Function intFunc) Integration(Function intFunc, double lowerLimit, double upperLimit) MappedExpander(Function function, MappedExpander.DomainMap map, int N) Uses Chebyshev Extrema nodes: u_k = cos(k * PI / N) for k = 0...N.NumericalDerivative(Function function, double xPoint) NumericalIntegral(Function f, double lower, double upper, int iterations, MethodHandle targetHandle, String[] vars, int[] slots) NumericalIntegral(Function f, MethodHandle methodHandle, String[] vars, int[] slots) NumericalIntegrator(Function function, MethodHandle gaussianHandle, double xLower, double xUpper, String[] vars, int[] slots) RootFinder(Function function) RootFinder(Function function, double x1) RootFinder(Function function, double x1, double x2) RootFinder(Function function, double x1, double x2, int iterations) -
Uses of Function in com.github.gbenroscience.parser
Methods in com.github.gbenroscience.parser that return FunctionModifier and TypeMethodDescriptionFunction.copy()Creates a deep copy of this Function instance.static Functionstatic FunctionFunction.storeAnonymousFunction(String expression) Methods in com.github.gbenroscience.parser with parameters of type Function -
Uses of Function in com.github.gbenroscience.parser.turbo.tools
Methods in com.github.gbenroscience.parser.turbo.tools with parameters of type FunctionModifier and TypeMethodDescriptionstatic doubleScalarTurboEvaluator1.executeTurboIntegral(Function f, MethodHandle handle, double lower, double upper, int iterations, String[] vars, int[] slots) static doubleScalarTurboEvaluator2.executeTurboIntegral(Function f, MethodHandle handle, double lower, double upper, int iterations, String[] vars, int[] slots) -
Uses of Function in com.github.gbenroscience.util
Fields in com.github.gbenroscience.util with type parameters of type FunctionMethods in com.github.gbenroscience.util that return FunctionModifier and TypeMethodDescriptionstatic Functionstatic FunctionAdds a Function object to this FunctionManager.static FunctionFunctionManager.getFunction(String fName) static FunctionSome actions require a handle being gotten on a function name.static FunctionFunctionManager.lockDownAnon(Function f) Creates the anonymous copy of a Functionstatic FunctionFunctionManager.lockDownAnon(String... independentVars) Create a dummy function to be populated with its true values later.static FunctionAttempts to retrieve a Function object from a FunctionManager based on its name.Methods in com.github.gbenroscience.util that return types with arguments of type FunctionMethods in com.github.gbenroscience.util with parameters of type FunctionModifier and TypeMethodDescriptionstatic Functionstatic FunctionFunctionManager.lockDownAnon(Function f) Creates the anonymous copy of a Functionstatic voidUpdates the Map with the most recent version of this Function.Method parameters in com.github.gbenroscience.util with type arguments of type FunctionModifier and TypeMethodDescriptionstatic voidstatic void -
Uses of Function in com.github.gbenroscience.util.io
Method parameters in com.github.gbenroscience.util.io with type arguments of type FunctionModifier and TypeMethodDescriptionstatic voidFunctionsBackup.readFileLinesToMap(Map<String, Function> map, File fileToRead) This reads the lines of text in a file into aMap.static voidFunctionsBackup.writeMapItemsToFileLineByLine(Map<String, Function> map, File file) This writes items on a queue to a file.