Uses of Class
com.github.gbenroscience.parser.MathExpression
Packages that use MathExpression
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of MathExpression in com.github.gbenroscience.math.matrix.expressParser
Subclasses of MathExpression in com.github.gbenroscience.math.matrix.expressParserMethods in com.github.gbenroscience.math.matrix.expressParser with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic voidMatrixOperator.orderCompoundTokens(MathExpression function) -
Uses of MathExpression in com.github.gbenroscience.math.numericalmethods
Methods in com.github.gbenroscience.math.numericalmethods with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic ComplexityAnalyst.StrategyComplexityAnalyst.selectStrategy(MathExpression expr) -
Uses of MathExpression in com.github.gbenroscience.math.otherBaseParser
Subclasses of MathExpression in com.github.gbenroscience.math.otherBaseParser -
Uses of MathExpression in com.github.gbenroscience.parser
Subclasses of MathExpression in com.github.gbenroscience.parserMethods in com.github.gbenroscience.parser that return MathExpressionModifier and TypeMethodDescriptionMathExpression.clone()MathExpression.copy()Manual deep copy method that will most certainly outperform the clone method.Function.getMathExpression()Methods in com.github.gbenroscience.parser with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic voidUnaryPreOperator.assignCompoundTokens(MathExpression function) voidFunction.setMathExpression(MathExpression mathExpression) voidNumber.validateNumber(MathExpression function) -
Uses of MathExpression in com.github.gbenroscience.parser.benchmarks
Fields in com.github.gbenroscience.parser.benchmarks with type parameters of type MathExpressionModifier and TypeFieldDescriptionstatic final ArrayList<MathExpression> MeCopyVsConstructor.TRASHMethods in com.github.gbenroscience.parser.benchmarks with parameters of type MathExpression -
Uses of MathExpression in com.github.gbenroscience.parser.turbo.tools
Methods in com.github.gbenroscience.parser.turbo.tools that return MathExpressionMethods in com.github.gbenroscience.parser.turbo.tools with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic TurboExpressionEvaluatorTurboEvaluatorFactory.getCompiler(MathExpression me) Intelligently selects and returns the best Turbo engine for the expression.static TurboExpressionEvaluatorTurboEvaluatorFactory.getCompiler(MathExpression me, boolean useWideningVarsPassing) Constructors in com.github.gbenroscience.parser.turbo.tools with parameters of type MathExpressionModifierConstructorDescriptionScalarTurboEvaluator(MathExpression me, boolean useWideningVars) USE THIS ONLY IF YOU KNOW WHAT YOU ARE DOING! -
Uses of MathExpression in com.github.gbenroscience.util
Methods in com.github.gbenroscience.util that return MathExpressionModifier and TypeMethodDescriptionMathExpressionManager.createFunction(String expr) MathExpressionManager.getFunction(MathExpression function) MathExpressionManager.getFunctionAt(int index) MathExpressionManager.getFunctionByExpression(String expression) MathExpressionManager.getFunctionByScanner(ArrayList<String> scanner) MathExpressionManager.optimizeFunction(String name) Methods in com.github.gbenroscience.util that return types with arguments of type MathExpressionMethods in com.github.gbenroscience.util with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic StringMathExpressionManager.analyzeSolution(MathExpression expr) booleanMathExpressionManager.contains(MathExpression func) MathExpressionManager.getFunction(MathExpression function) voidMathExpressionManager.storeFunction(MathExpression function) stores a MathExpression in objects of this class.Method parameters in com.github.gbenroscience.util with type arguments of type MathExpressionModifier and TypeMethodDescriptionvoidMathExpressionManager.setFunctions(ArrayList<MathExpression> functions)