Uses of Interface
com.github.gbenroscience.parser.Validatable
Packages that use Validatable
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Validatable in com.github.gbenroscience.math.matrix.expressParser
Classes in com.github.gbenroscience.math.matrix.expressParser that implement ValidatableModifier and TypeClassDescriptionfinal classclassclassfinal classfinal classclassModels a post-operand MOperator object e.g the !, inverse, square, cube operators -
Uses of Validatable in com.github.gbenroscience.parser
Classes in com.github.gbenroscience.parser that implement ValidatableModifier and TypeClassDescriptionfinal classfinal classclassfinal classfinal classfinal classExamples are sort function, mode function and other methods that will return a list of numbers after acting on a number or a list of numbersclassclassfinal classfinal classclassDeals with number returning statistical operators e.g sum,avg,mode e.t.c and log and antilog to any base operatorsfinal classfinal classfinal classfinal classclassModels a post-operand Operator object e.g the !, inverse, square, cube operatorsfinal classModels a post-operand Operator object e.g the trigonometric,logarithmic,exponential e.t.c.