Interface MethodRegistry.MethodAction

All Superinterfaces:
Savable, Serializable
All Known Implementing Classes:
Function
Enclosing class:
MethodRegistry

public static interface MethodRegistry.MethodAction extends Savable
Author:
GBEMIRO
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final long
     
  • Method Summary

    Modifier and Type
    Method
    Description
    calc(MathExpression.EvalResult nextResult, int arity, MathExpression.EvalResult[] args)
    Allows methods like diff(fn,args) to differentiate an expression using the MethodRegistry interface Is the intersection between methods and user-defined functions

    Methods inherited from interface com.github.gbenroscience.interfaces.Savable

    serialize
  • Field Details

  • Method Details

    • calc

      Allows methods like diff(fn,args) to differentiate an expression using the MethodRegistry interface Is the intersection between methods and user-defined functions
      Parameters:
      nextResult -
      arity - The number of argument to read from the args array
      args - The args passed to the function
      Returns: