Interface FastExpression

Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface FastExpression
Author:
GBEMIRO Functional interface for turbo-compiled expressions. Generated bytecode implements this directly.
  • Method Summary

    Modifier and Type
    Method
    Description
    double
    apply(double[] variables)
    Evaluate expression with given variable values.
  • Method Details

    • apply

      double apply(double[] variables)
      Evaluate expression with given variable values.
      Parameters:
      variables - array of variable values (index corresponds to variable slot)
      Returns:
      result of expression evaluation