Interface QuickTime.Timable
- Enclosing class:
QuickTime
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Functional interface for the method to be timed.
- Author:
- GBEMIRO
-
Method Summary
-
Method Details
-
run
void run()
-