Uses of Interface
com.github.gbenroscience.parser.turbo.QuickTime.Timable
Packages that use QuickTime.Timable
-
Uses of QuickTime.Timable in com.github.gbenroscience.parser.turbo
Methods in com.github.gbenroscience.parser.turbo with parameters of type QuickTime.TimableModifier and TypeMethodDescriptionstatic doubleQuickTime.benchmarkNano(String label, int warmups, int iterations, QuickTime.Timable task) Times a method over multiple iterations and returns the average.static voidQuickTime.report(String label, QuickTime.Timable task) Prints a formatted report of the execution time.static longQuickTime.timeNano(QuickTime.Timable task) Times a single execution of a method in nanoseconds.