Class MatrixTurboEvaluator.ResultCache
java.lang.Object
com.github.gbenroscience.parser.turbo.tools.MatrixTurboEvaluator.ResultCache
- Enclosing class:
MatrixTurboEvaluator
Holds the mutable state for a single node in the execution tree. Bound
into the MethodHandle chain at compile-time.
-
Field Summary
FieldsModifier and TypeFieldDescriptiondouble[]double[] -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiondouble[]getEigenBuffer(int n) getMatrixBuffer(int rows, int cols) getSecondaryBuffer(int rows, int cols) Provides a secondary buffer to avoid overwriting primary data during complex loops like power functions.getTertiaryBuffer(int rows, int cols)
-
Field Details
-
result
-
matrixData
public double[] matrixData -
matrix
-
eigenValueBuffer
public double[] eigenValueBuffer
-
-
Constructor Details
-
ResultCache
public ResultCache()
-
-
Method Details
-
getMatrixBuffer
-
getSecondaryBuffer
Provides a secondary buffer to avoid overwriting primary data during complex loops like power functions.- Parameters:
rows-cols-- Returns:
-
getTertiaryBuffer
-
getEigenBuffer
public double[] getEigenBuffer(int n)
-