Class ScalarTurboEvaluator

java.lang.Object
com.github.gbenroscience.parser.turbo.tools.ScalarTurboEvaluator
All Implemented Interfaces:
TurboExpressionEvaluator

public class ScalarTurboEvaluator extends Object implements TurboExpressionEvaluator
Author:
GBEMIRO
  • Field Details

    • MIN_VAR_COUNT_FOR_ARRAY_BASED_EVALUATOR

      public static final int MIN_VAR_COUNT_FOR_ARRAY_BASED_EVALUATOR
      If the number of unique variables in the expression is equal to or greater than MIN_VAR_COUNT_FOR_ARRAY_BASED_EVALUATOR, the Array based evaluator will be used
      See Also:
    • MAX_ALLOWED_METHOD_ARGS_BY_JVM

      public static final int MAX_ALLOWED_METHOD_ARGS_BY_JVM
      See Also:
  • Constructor Details

    • ScalarTurboEvaluator

      public ScalarTurboEvaluator(MathExpression me)
    • ScalarTurboEvaluator

      public ScalarTurboEvaluator(MathExpression me, boolean useWideningVars)
      USE THIS ONLY IF YOU KNOW WHAT YOU ARE DOING!
      Parameters:
      me - The root MathExpression
      useWideningVars - If true, you want the turbo evaluator to pass the variables to the evaluator with a widening approach. If false, it will pass it with an array based approach.
  • Method Details