Class ScalarTurboEvaluator1.AndroidFriendlyMethodHandles
java.lang.Object
com.github.gbenroscience.parser.turbo.tools.ScalarTurboEvaluator1.AndroidFriendlyMethodHandles
- Enclosing class:
ScalarTurboEvaluator1
- Author:
- GBEMIRO
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic doublefallbackGetDouble(double[] array, int index) Static helper used as a MethodHandle target on Android.static MethodHandleReturns the most efficient getter available for the current platform.
-
Constructor Details
-
AndroidFriendlyMethodHandles
public AndroidFriendlyMethodHandles()
-
-
Method Details
-
fallbackGetDouble
public static double fallbackGetDouble(double[] array, int index) Static helper used as a MethodHandle target on Android.- Parameters:
array-index-- Returns:
-
getDoubleArrayGetter
Returns the most efficient getter available for the current platform.
-