Class ScalarTurboEvaluator2.MethodHandlePolyfill
java.lang.Object
com.github.gbenroscience.parser.turbo.tools.ScalarTurboEvaluator2.MethodHandlePolyfill
- Enclosing class:
ScalarTurboEvaluator2
- Author:
- GBEMIRO
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic MethodHandleDrop-in replacement for MethodHandles.identity() that chooses the most performant path based on the environment.
-
Constructor Details
-
MethodHandlePolyfill
public MethodHandlePolyfill()
-
-
Method Details
-
identity
Drop-in replacement for MethodHandles.identity() that chooses the most performant path based on the environment.- Parameters:
type-- Returns:
-