Interface TurboExpressionEvaluator

All Known Implementing Classes:
MatrixTurboEvaluator, ScalarTurboEvaluator, ScalarTurboEvaluator1, ScalarTurboEvaluator2

public interface TurboExpressionEvaluator
Author:
GBEMIRO Interface for turbo compilers that generate optimized bytecode expressions. Different implementations can be used for scalar, matrix, or hybrid operations.
  • Method Summary

    Modifier and Type
    Method
    Description
    Compile a postfix token array into a fast-executing expression.
  • Method Details

    • compile

      Compile a postfix token array into a fast-executing expression.
      Returns:
      A FastCompositeExpression ready for evaluation
      Throws:
      Throwable - if compilation fails