Enum ErrorLog.Level

java.lang.Object
java.lang.Enum<ErrorLog.Level>
com.github.gbenroscience.util.ErrorLog.Level
All Implemented Interfaces:
Serializable, Comparable<ErrorLog.Level>, java.lang.constant.Constable
Enclosing class:
ErrorLog

public static enum ErrorLog.Level extends Enum<ErrorLog.Level>
Author:
JIBOYE Oluwagbemiro Olaoluwa
  • Enum Constant Details

  • Method Details

    • values

      public static ErrorLog.Level[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static ErrorLog.Level valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null