Class Serializer
java.lang.Object
com.github.gbenroscience.util.Serializer
- Author:
- GBEMIRO JIBOYE
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
Serializer
public Serializer()
-
-
Method Details
-
serialize
-
deserialize
-
getBytes
- Parameters:
ser- The serialized format for the byte array of the object- Returns:
- the byte array from the serialized format of the object
-
ser
Prepare the byte array- Parameters:
yourObject-- Returns:
-
main
-