Class Utils
java.lang.Object
com.github.gbenroscience.util.Utils
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic booleanstatic booleanisPerfectSquare(int num) static voidloadAll()static voidloads the stored functions from persistent storagestatic Settingsstatic voidstatic voidstatic voidstatic voidstatic voidstatic voidstatic voidstatic voidsaveSettings(Settings settings) Saves the settingsstatic void
-
Field Details
-
VARIABLES
This file contains a record of all Variables -
FUNCTIONS
This file contains a record of all Functions -
SETTINGS
This file contains a record of all Settings -
APP_FOLDER
-
IMAGE_ICON_SIZE
public static int IMAGE_ICON_SIZE -
loggingEnabled
public static boolean loggingEnabled
-
-
Constructor Details
-
Utils
public Utils()
-
-
Method Details
-
saveVariables
public static void saveVariables() -
loadVariables
public static void loadVariables() -
saveFunctions
public static void saveFunctions() -
loadFunctions
public static void loadFunctions()loads the stored functions from persistent storage -
saveSettings
Saves the settings -
loadSettings
-
saveAll
-
loadAll
public static void loadAll() -
logError
-
logDebug
-
logInfo
-
isAndroid
public static boolean isAndroid() -
isPerfectSquare
public static boolean isPerfectSquare(int num) -
main
-