Uses of Enum
com.github.gbenroscience.util.ErrorLog.Level
Packages that use ErrorLog.Level
-
Uses of ErrorLog.Level in com.github.gbenroscience.util
Subclasses with type arguments of type ErrorLog.Level in com.github.gbenroscience.utilMethods in com.github.gbenroscience.util that return ErrorLog.LevelModifier and TypeMethodDescriptionstatic ErrorLog.LevelReturns the enum constant of this type with the specified name.static ErrorLog.Level[]ErrorLog.Level.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.github.gbenroscience.util with parameters of type ErrorLog.LevelModifier and TypeMethodDescriptionvoidErrorLog.log(ErrorLog.Level level, String message) Logs a message with a specific severity level.