Uses of Class
com.github.gbenroscience.util.SimplePoint
Packages that use SimplePoint
-
Uses of SimplePoint in com.github.gbenroscience.math
Methods in com.github.gbenroscience.math that return SimplePointModifier and TypeMethodDescriptionPoint.getUtilPoint()Converts objects of this class to the normal Point object.static SimplePointPoint.getUtilPoint(Point point) Converts objects of this class to the normal Point object. -
Uses of SimplePoint in com.github.gbenroscience.util
Constructors in com.github.gbenroscience.util with parameters of type SimplePoint