Uses of Class
com.github.gbenroscience.util.VariableManager
Packages that use VariableManager
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of VariableManager in com.github.gbenroscience.math.matrix.expressParser
Methods in com.github.gbenroscience.math.matrix.expressParser with parameters of type VariableManagerModifier and TypeMethodDescriptionMatrixExpressionScanner.scanner(MatrixVariableManager matrixvarman, VariableManager varMan) Utility method,more popularly used as a scanner into mathematical tokens of mathematical expressionsMmathScanner.scanner(VariableManager varMan) Utility method,more popularly used as a scanner into mathematical tokens of mathematical expressions -
Uses of VariableManager in com.github.gbenroscience.parser
Methods in com.github.gbenroscience.parser that return VariableManagerMethods in com.github.gbenroscience.parser with parameters of type VariableManagerModifier and TypeMethodDescriptionMathScanner.scanner(VariableManager varMan) Utility method,more popularly used as a scanner into mathematical tokens of mathematical expressionsvoidMathExpression.setVariableManager(VariableManager variableManager) Constructors in com.github.gbenroscience.parser with parameters of type VariableManagerModifierConstructorDescriptionMathExpression(String input, VariableManager variableManager, boolean foldConstants) -
Uses of VariableManager in com.github.gbenroscience.util
Methods in com.github.gbenroscience.util that return VariableManagerModifier and TypeMethodDescriptionMathExpressionManager.getVariableManager()A workspace uses a MathExpressionManager to manage and optimize functions used in calculations.