Package com.github.gbenroscience.util
package com.github.gbenroscience.util
-
ClassDescriptionA utility class that tracks errors and warnings during parsing operations.Objects of this class attempt to optimize and then evaluate a math expression.Is thrown whenever an illegal matrix string is found.1.Test Class: Must be static so it doesn't try to serialize the "Serializer" class along with it.Created by hp on 7/7/2016.Objects of this class supply methods that may be used for telling time and parsing String representations of time in dd:hh:mm:ss or hh:mm:ss or hh:mm formats and translating them into seconds formats.The reverse is also possible:i.e translating time in seconds into dd:hh:mm:ss format.