Uses of Package
com.github.gbenroscience.util
Packages that use com.github.gbenroscience.util
Package
Description
Classes designed to parse a mathematical expression.
-
Classes in com.github.gbenroscience.util used by com.github.gbenroscience.logicClassDescriptionObjects of this class attempt to optimize and then evaluate a math expression.Created by hp on 7/7/2016.
-
Classes in com.github.gbenroscience.util used by com.github.gbenroscience.math
-
Classes in com.github.gbenroscience.util used by com.github.gbenroscience.math.graph
-
Classes in com.github.gbenroscience.util used by com.github.gbenroscience.math.matrix.expressParserClassDescriptionIs thrown whenever an illegal matrix string is found.
-
Classes in com.github.gbenroscience.util used by com.github.gbenroscience.parserClassDescriptionA utility class that tracks errors and warnings during parsing operations.
-
Classes in com.github.gbenroscience.util used by com.github.gbenroscience.utilClassDescriptionA utility class that tracks errors and warnings during parsing operations.Created by hp on 7/7/2016.Objects of this class supply methods that may be used for telling time and parsing String representations of time in dd:hh:mm:ss or hh:mm:ss or hh:mm formats and translating them into seconds formats.The reverse is also possible:i.e translating time in seconds into dd:hh:mm:ss format.Objects of this class parse a variable initialization or modifying command string.