Package logic
Class OperatingSystem
java.lang.Object
logic.OperatingSystem
public class OperatingSystem
extends java.lang.Object
Objects of this class will control the running modes of the calculator.
And so enable the user to use a single button such as the equals button to act on many kinds of input.
e.g calculate,integrate,solve equations,store objects and so on.
This class will be involved with the different threads that may be spawned by the software in future.
- Author:
- GBEMIRO
-
Constructor Summary
Constructors Constructor Description OperatingSystem() -
Method Summary
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Constructor Details
-
OperatingSystem
public OperatingSystem()
-
-
Method Details
-
getTask
- Returns:
- the Task object
-
setTask
- Parameters:
task- sets the Task object
-
execute
method responsible for recognizing commands entered into the command line or text field and executing them.- Parameters:
task- the command to be executed.
-