Packages that use Size
| Package |
Description |
| math |
|
-
Methods in math that return Size
| Modifier and Type |
Method |
Description |
Size |
Size.getScaledInstance(double scaleFactor) |
returns a new Size object scaled to the value given by scaleFactor
|
Size |
Size.getScaledInstance(double scaleWidth,
double scaleHeight) |
returns a new Size object scaled to the value given by scaleWidth
and scaleHeight, both being muktipliers for the width and the
height.
|
Size |
Size.getSize() |
|
Methods in math with parameters of type Size
| Modifier and Type |
Method |
Description |
void |
Size.setSize(Size size) |
|
Constructors in math with parameters of type Size
| Constructor |
Description |
Size(Size size) |
Creates a new Size object from
a given Size object.
|