-
Class Summary
| Class |
Description |
| HalfDet |
|
| MAdditionOperator |
|
| MAssignmentOperator |
|
| Matrix |
|
| MatrixBinaryOperator |
|
| MatrixExpressionScanner |
|
| MatrixFunction |
|
| MatrixOperator |
|
| MatrixValueParser |
Objects of this class extract a matrix from an input expression of the
format:
[num1,num2,...:num_i,num_i+1,....:num_j,num_j+1...: ] e.g [2,3,4:4,1,2:...]
The colons represent the end of one row of values and the beginning of
another.
|
| MatrixVariable |
|
| MBinaryOperator |
|
| MBracket |
|
| MLogic |
|
| MmathScanner |
|
| MmultiplicationOperator |
|
| MNumber |
|
| MOperator |
|
| MSet |
Class that provides utility methods for carrying
out statistical analysis on a data set consisting of real numbers.
|
| MSubtractionOperator |
|
| MUnaryPostOperator |
Models a post-operand MOperator
object e.g the !, inverse, square, cube operators
|
| PrecisionMatrix |
Deals with numbers of higher
precision than Matrix.
|