Class LinearSystemGenerator

java.lang.Object
math.matrix.util.LinearSystemGenerator

public class LinearSystemGenerator
extends java.lang.Object
Objects of this class have the ability to generate a system of linear equations, randomly.
Author:
JIBOYE Oluwagbemiro Olaoluwa
  • Constructor Details

    • LinearSystemGenerator

      public LinearSystemGenerator​(int size, int maximumPossibleNumberInSystem, java.lang.String startingLetterOfUnknownName)
      Parameters:
      size - The number of unknowns that the system will have.
      maximumPossibleNumberInSystem - The absolute value of the largest possible number that may be found in the system.
      startingLetterOfUnknownName - The letter of the alphabet that will start the name of the unknown.
  • Method Details

    • setStartingLetterOfUnknownName

      public void setStartingLetterOfUnknownName​(java.lang.String startingLetterOfUnknownName)
    • getStartingLetterOfUnknownName

      public java.lang.String getStartingLetterOfUnknownName()
    • setSize

      public void setSize​(int size)
    • getSize

      public int getSize()
    • setMaximumPossibleNumberInSystem

      public void setMaximumPossibleNumberInSystem​(int maximumPossibleNumberInSystem)
    • getMaximumPossibleNumberInSystem

      public int getMaximumPossibleNumberInSystem()
    • main

      public static void main​(java.lang.String[] args)