Package math.quadratic
Class QuadraticExpressionParser
java.lang.Object
math.quadratic.QuadraticExpressionParser
public class QuadraticExpressionParser
extends java.lang.Object
- Author:
- JIBOYE Oluwagbemiro Olaoluwa
-
Constructor Summary
Constructors Constructor Description QuadraticExpressionParser(java.lang.String expression) -
Method Summary
Modifier and Type Method Description voidappendOneToStartOfFreeVariables()When the situation x+2y+z=9; is met, this method will convert it into 1.0x+2y+z=9;voiddoArithmetic()This method initializes the coefficients field with the coefficient of Xsquared at index 0 the coefficient of X at index 1 the coefficient of the constant term at index 2voidfreeWhiteSpaces()removes white space from the ArrayListjava.util.ArrayList<java.lang.Double>getCoefficients()java.lang.StringgetExpression()java.util.ArrayList<java.lang.String>getScanner()java.lang.StringgetUnknown()java.lang.StringinterpretedSystem()booleanisValid()static voidmain(java.lang.String[] args)voidrecognizeCompoundVariables()turns the Xsquare into a single variable.voidrecognizeNegativesAndPositives()voidsetExpression(java.lang.String expression)voidsetScanner(java.util.ArrayList<java.lang.String> scanner)voidsetValid(boolean valid)voidvalidateChars()Checks the character set of this parser.voidvalidateEqualsSymbol()voidvalidateNumbers()Checks the left and right of a number to see if the appropriate items are the ones there.voidvalidateVars()Checks if the variables are properly arranged wrt other tokens.Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Constructor Details
-
QuadraticExpressionParser
public QuadraticExpressionParser(java.lang.String expression)
-
-
Method Details
-
getCoefficients
public java.util.ArrayList<java.lang.Double> getCoefficients()- Returns:
- the coefficients ArrayList object.
-
freeWhiteSpaces
public void freeWhiteSpaces()removes white space from the ArrayList -
setValid
public void setValid(boolean valid) -
isValid
public boolean isValid() -
setScanner
public void setScanner(java.util.ArrayList<java.lang.String> scanner) -
getScanner
public java.util.ArrayList<java.lang.String> getScanner() -
setExpression
public void setExpression(java.lang.String expression) -
getExpression
public java.lang.String getExpression() -
appendOneToStartOfFreeVariables
public void appendOneToStartOfFreeVariables()When the situation x+2y+z=9; is met, this method will convert it into 1.0x+2y+z=9; -
validateEqualsSymbol
public void validateEqualsSymbol() -
validateChars
public void validateChars()Checks the character set of this parser. -
validateVars
public void validateVars()Checks if the variables are properly arranged wrt other tokens. -
validateNumbers
public void validateNumbers()Checks the left and right of a number to see if the appropriate items are the ones there. It is a syntax error if an invalid item is found there -
recognizeNegativesAndPositives
public void recognizeNegativesAndPositives() -
recognizeCompoundVariables
public void recognizeCompoundVariables()turns the Xsquare into a single variable. -
getUnknown
public java.lang.String getUnknown()- Returns:
- the name of the unknown.
-
doArithmetic
public void doArithmetic()This method initializes the coefficients field with the coefficient of Xsquared at index 0 the coefficient of X at index 1 the coefficient of the constant term at index 2 -
interpretedSystem
public java.lang.String interpretedSystem()- Returns:
- the reduced form of the system in the form Ax²+Bx+C=0;
-
main
public static void main(java.lang.String[] args)
-