Uses of Enum Class
com.github.gbenroscience.math.graph.tools.FontStyle
Packages that use FontStyle
-
Uses of FontStyle in com.github.gbenroscience.math.graph.tools
Subclasses with type arguments of type FontStyle in com.github.gbenroscience.math.graph.toolsMethods in com.github.gbenroscience.math.graph.tools that return FontStyleModifier and TypeMethodDescriptionGraphFont.getStyle()static FontStyleReturns the enum constant of this class with the specified name.static FontStyle[]FontStyle.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in com.github.gbenroscience.math.graph.tools with parameters of type FontStyleConstructors in com.github.gbenroscience.math.graph.tools with parameters of type FontStyle