Package com.github.gbenroscience.math.matrix.expressParser
package com.github.gbenroscience.math.matrix.expressParser
-
ClassesClassDescriptionClass that provides utility methods for carrying out statistical analysis on a data set consisting of real numbers.Deals with numbers of higher precision than Matrix.