Uses of Enum Class
com.github.gbenroscience.parser.OperatorConstant
Packages that use OperatorConstant
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of OperatorConstant in com.github.gbenroscience.parser
Subclasses with type arguments of type OperatorConstant in com.github.gbenroscience.parserMethods in com.github.gbenroscience.parser that return OperatorConstantModifier and TypeMethodDescriptionstatic OperatorConstantOperatorConstant.fromString(String s) Handy method to get the actual Enum from a stringstatic OperatorConstantReturns the enum constant of this class with the specified name.static OperatorConstant[]OperatorConstant.values()Returns an array containing the constants of this enum class, in the order they are declared.