Class KernelInterceptException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.github.gbenroscience.parser.turbo.tools.exceptions.KernelInterceptException
All Implemented Interfaces:
Serializable

public class KernelInterceptException extends RuntimeException
Author:
GBEMIRO An internal control-flow signal thrown during AST compilation to indicate that a function should be routed to a FlatMatrix kernel instead of being compiled into a standard lane-by-lane vector tree.
See Also:
  • Constructor Details

    • KernelInterceptException

      public KernelInterceptException(String kernelName, int expectedArity)
  • Method Details

    • getKernelName

      public String getKernelName()
    • getExpectedArity

      public int getExpectedArity()
    • fillInStackTrace

      public Throwable fillInStackTrace()
      Overrides:
      fillInStackTrace in class Throwable