Uses of Class
parser.Operator
-
Packages that use Operator Package Description math.matrix.expressParser parser Classes designed to parse a mathematical expression. -
-
Uses of Operator in math.matrix.expressParser
Subclasses of Operator in math.matrix.expressParser Modifier and Type Class Description classMAdditionOperatorclassMatrixBinaryOperatorclassMBinaryOperatorclassMBracketclassMmultiplicationOperatorclassMOperatorclassMSubtractionOperatorclassMUnaryPostOperatorModels a post-operand MOperator object e.g the !, inverse, square, cube operators -
Uses of Operator in parser
Subclasses of Operator in parser Modifier and Type Class Description classAdditionOperatorclassAntiLogToAnyBaseclassBinaryOperatorclassBracketclassCombinationOperatorclassDivisionOperatorclassListReturningStatsOperatorclassLogicOperatorclassLogOrAntiLogToAnyBaseclassLogToAnyBaseclassMultiplicationOperatorclassNumberReturningStatsOperatorDeals with number returning statistical operators e.g sum,avg,mode e.t.c and log and antilog to any base operatorsclassPermutationOperatorclassPowerOperatorclassRemainderOperatorclassSubtractionOperatorclassUnaryPostOperatorModels a post-operand Operator object e.g the !, inverse, square, cube operatorsclassUnaryPreOperatorModels a post-operand Operator object e.g the trigonometric,logarithmic,exponential e.t.c.
-