Serialized Form
-
Package com.github.gbenroscience.interfaces
-
Package com.github.gbenroscience.logic
-
Class com.github.gbenroscience.logic.CalcLogic
class CalcLogic extends Object implements Serializable-
Serialized Fields
-
baseMode
BASE_MODE baseMode
-
commandHistory
ArrayList<String> commandHistory
Stores the commands used on the CommandLineActivity -
drgMode
DRG_MODE drgMode
-
formMan
FormulaeManager formMan
-
funcMan
MathExpressionManager funcMan
-
histMan
HistoryManager histMan
-
justEvaluated
boolean justEvaluated
When true, the calculator is in a state wherein the last action it performed was the evaluation of an expression. -
manager
OperatingSystem manager
-
mode
Mode mode
-
powerMode
POWER_MODE powerMode
-
running
boolean running
-
settings
Settings settings
-
trigMode
TRIG_MODE trigMode
-
useMode
USE_MODE useMode
-
vibrateOn
boolean vibrateOn
-
-
-
-
Package com.github.gbenroscience.math.matrix.expressParser
-
Class com.github.gbenroscience.math.matrix.expressParser.MatrixExpression
class MatrixExpression extends MathExpression implements Serializable -
Class com.github.gbenroscience.math.matrix.expressParser.MatrixFunction
class MatrixFunction extends MathExpression implements Serializable
-
-
Package com.github.gbenroscience.math.otherBaseParser
-
Class com.github.gbenroscience.math.otherBaseParser.BaseNFunction
class BaseNFunction extends MathExpression implements Serializable-
Serialized Fields
-
baseOfOperation
int baseOfOperation
The number base that objects of this class will use in computations.
-
-
-
-
Package com.github.gbenroscience.parser
-
Class com.github.gbenroscience.parser.Function
class Function extends Object implements Serializable-
Serialized Fields
-
dependentVariable
Variable dependentVariable
The dependent variable -
independentVariables
ArrayList<Variable> independentVariables
The independent variables. -
mathExpression
MathExpression mathExpression
If the object is an algebraic expression, its details are stored here. The math expression on the RHS. -
matrix
Matrix matrix
If the object is aMatrixits data is stored here. -
turboExpr
FastCompositeExpression turboExpr
-
type
TYPE type
The type of the function
-
-
-
Class com.github.gbenroscience.parser.MathExpression
class MathExpression extends Object implements Serializable-
Serialized Fields
-
cachedPostfix
MathExpression.Token[] cachedPostfix
-
commaAlias
String commaAlias
Backup the alias from the scanner here -
compiledTurbo
FastCompositeExpression compiledTurbo
-
correctFunction
boolean correctFunction
-
DRG
DRG_MODE DRG
-
executionFrame
double[] executionFrame
-
expression
String expression
The expression to evaluate. -
expressionSolver
com.github.gbenroscience.parser.MathExpression.ExpressionSolver expressionSolver
-
hasFunctionOrVariableInitStatement
boolean hasFunctionOrVariableInitStatement
Set this attribute to true, if and only if the input into this system is meant to initialize or change the value of variable data alone and is not calculating a standalone math expression. For example, var a =2;var b=3;var c=cos(a-b);f(x)=3*x^2; d=3cos(c); where c has been declared before! -
hasListReturningOperators
boolean hasListReturningOperators
-
help
boolean help
-
noOfListReturningOperators
int noOfListReturningOperators
-
optimizable
boolean optimizable
-
parser_Result
ParserResult parser_Result
-
pool
MathExpression.EvalResult[] pool
-
poolPointer
int poolPointer
-
registry
MathExpression.VariableRegistry registry
-
returnObjectName
String returnObjectName
Sometimes, after evaluation the evaluation list which is a local variable, is reduced to a function name(or other object as time goes on) instead of a number of other list. The parser unfortunately will not return this variable, but instead returns the data which it refers to..e.g aMatrixfunction or other. But we atimes need that function name...So we cache this value here. -
returnType
TYPE returnType
The kind of output returned by the parser. -
scanner
List<String> scanner
-
slots
int[] slots
-
treeStats
MathExpressionTreeDepth.Result treeStats
-
turboCompiled
boolean turboCompiled
-
variableManager
VariableManager variableManager
The VariableManager object that allows an object of this class to remember its variables. -
whitespaceremover
ArrayList<String> whitespaceremover
-
willFoldConstants
boolean willFoldConstants
If set to true, the constants folding algorithm will be run to further optimize the compiled postfix and so make the speed of evaluation faster.
-
-
-
Exception Class com.github.gbenroscience.parser.ParserException
class ParserException extends InputMismatchException implements Serializable -
Class com.github.gbenroscience.parser.PolynomialExpression
class PolynomialExpression extends MathExpression implements Serializable-
Serialized Fields
-
hasMulOrDivOps
boolean hasMulOrDivOps
-
hasPlusOrMinusOps
boolean hasPlusOrMinusOps
-
hasPowerOps
boolean hasPowerOps
-
precision
int precision
Used to select what mode to operate objects of this class...whether DOUBLE_PRECISION or BIGDECIMAL_PRECISION.
-
-
-
Class com.github.gbenroscience.parser.Variable
class Variable extends Object implements Serializable-
Serialized Fields
-
constant
boolean constant
-
frameIndex
int frameIndex
THE SECRET SAUCE: The Frame Index. This represents the variable's "Drawer Number" in the execution frame. Initialized to -1 to indicate it hasn't been mapped yet. -
fullName
String fullName
The full name of the variable -
name
String name
-
type
TYPE type
-
units
String units
-
value
double value
-
-
-
-
Package com.github.gbenroscience.util
-
Exception Class com.github.gbenroscience.util.MatrixFormatException
class MatrixFormatException extends Exception implements Serializable -
Class com.github.gbenroscience.util.Settings
class Settings extends Object implements Serializable
-
-
Package com.github.gbenroscience.util.help
-
Class com.github.gbenroscience.util.help.Topic
class Topic extends Object implements Serializable
-
-
Package com.github.gbenroscience.util.io
-
Class com.github.gbenroscience.util.io.TextFileWriter
class TextFileWriter extends Object implements Serializable-
Serialized Fields
-
filePath
String filePath
-
output
ObjectOutputStream output
-
-
-