Uses of Interface
com.github.gbenroscience.interfaces.Savable
Packages that use Savable
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Savable in com.github.gbenroscience.logic
Classes in com.github.gbenroscience.logic that implement Savable -
Uses of Savable in com.github.gbenroscience.math.matrix.expressParser
Classes in com.github.gbenroscience.math.matrix.expressParser that implement Savable -
Uses of Savable in com.github.gbenroscience.math.otherBaseParser
Classes in com.github.gbenroscience.math.otherBaseParser that implement Savable -
Uses of Savable in com.github.gbenroscience.parser
Classes in com.github.gbenroscience.parser that implement SavableModifier and TypeClassDescriptionclassclassThis class is NOT thread-safe.static final classstatic final classstatic final classstatic final classManages the mapping of variable names to frame slots.classOptimized Java class to compute the depth (height) of the abstract syntax tree (AST) for a mathematical expression.static classclassclass -
Uses of Savable in com.github.gbenroscience.util
Classes in com.github.gbenroscience.util that implement SavableModifier and TypeClassDescriptionstatic classTest Class: Must be static so it doesn't try to serialize the "Serializer" class along with it.classCreated by hp on 7/7/2016.Methods in com.github.gbenroscience.util that return SavableModifier and TypeMethodDescriptionstatic final SavableSerializer.deserialize(String encoded) Reconstructs an object from a Base64 encoded string.Methods in com.github.gbenroscience.util with parameters of type Savable -
Uses of Savable in com.github.gbenroscience.util.help
Classes in com.github.gbenroscience.util.help that implement SavableModifier and TypeClassDescriptionclassCreated by JIBOYE Oluwagbemiro Olaoluwa on 8/5/2016.