Class CodeGenerator
java.lang.Object
com.github.gbenroscience.math.differentialcalculus.CodeGenerator
Objects of this class take the output of the semantic
analyzer and uses it to generate code that the derivative engine can
work with.
- Author:
- GBEMIRO
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic voidstatic voidOpen up unnecessary brackets..e.g.static voidsimplifyTokens(ArrayList<String> scan) Coordinating method to generate math code almost ready for calculus.toString()
-
Constructor Details
-
CodeGenerator
-
-
Method Details
-
getScanner
-
simplifyTokens
-
openUpUnnecessaryBrackets
-
toString
-
main
-