Class ExpressionSimplifier
java.lang.Object
com.github.gbenroscience.math.differentialcalculus.ExpressionSimplifier
Objects of this class seek to
simplify a math expression, by taking it
through a series of transformative processes.
- Author:
- GBEMIRO
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic voidsimplifyCompoundBrackets(List<String> list) Simplifies tokens in a List that have no + or - operator, but may have brackets.Used by the main parser solve to figure out SBP portions of a multi-bracketed expression (MBP)
-
Constructor Details
-
ExpressionSimplifier
-
-
Method Details
-
getSimplifiedExpression
-
simplifyCompoundBrackets
-
solve
-