Class GraphElement
java.lang.Object
com.github.gbenroscience.math.graph.GraphElement
Created by JIBOYE Oluwagbemiro Olaoluwa on 6/28/2016.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic intbinarySearch(double searchValue, double[] array) voidfillCoords(double xLower, double xUpper, double xStep, double yStep, int drg, boolean useTurbo) double[]double[]static voidvoidsetFunction(String function) voidsetFunctionName(String functionName) voidsetGraphType(GraphType graphType) voidsetHorizontalCoordinates(double[] horizontalCoordinates) voidsetVerticalCoordinates(double[] verticalCoordinates) toString()
-
Constructor Details
-
GraphElement
-
-
Method Details
-
getFunctionName
-
setFunctionName
-
setGraphType
-
getGraphType
-
setFunction
-
getFunction
-
getHorizontalCoordinates
public double[] getHorizontalCoordinates() -
setHorizontalCoordinates
public void setHorizontalCoordinates(double[] horizontalCoordinates) -
setVerticalCoordinates
public void setVerticalCoordinates(double[] verticalCoordinates) -
getVerticalCoordinates
public double[] getVerticalCoordinates() -
fillCoords
public void fillCoords(double xLower, double xUpper, double xStep, double yStep, int drg, boolean useTurbo) -
binarySearch
public static int binarySearch(double searchValue, double[] array) - Parameters:
searchValue- The item whose index we are trying to estimate.array- The array to conduct binarySearch on- Returns:
- the index in the array where this item would be best placed. This
index is such that any element to its left would be less than
searchValueand any element to its right or atindexwould be greater than or equal to it.
-
toString
-
main
-