Class LinearSystemGenerator
java.lang.Object
com.github.gbenroscience.math.matrix.util.LinearSystemGenerator
Objects of this class have the ability to generate a
system of linear equations, randomly.
- Author:
- JIBOYE Oluwagbemiro Olaoluwa
-
Constructor Summary
ConstructorsConstructorDescriptionLinearSystemGenerator(int size, int maximumPossibleNumberInSystem, String startingLetterOfUnknownName) -
Method Summary
Modifier and TypeMethodDescriptionintintgetSize()static voidvoidsetMaximumPossibleNumberInSystem(int maximumPossibleNumberInSystem) voidsetSize(int size) voidsetStartingLetterOfUnknownName(String startingLetterOfUnknownName)
-
Constructor Details
-
LinearSystemGenerator
public LinearSystemGenerator(int size, int maximumPossibleNumberInSystem, String startingLetterOfUnknownName) - Parameters:
size- The number of unknowns that the system will have.maximumPossibleNumberInSystem- The absolute value of the largest possible number that may be found in the system.startingLetterOfUnknownName- The letter of the alphabet that will start the name of the unknown.
-
-
Method Details
-
setStartingLetterOfUnknownName
-
getStartingLetterOfUnknownName
-
setSize
public void setSize(int size) -
getSize
public int getSize() -
setMaximumPossibleNumberInSystem
public void setMaximumPossibleNumberInSystem(int maximumPossibleNumberInSystem) -
getMaximumPossibleNumberInSystem
public int getMaximumPossibleNumberInSystem() -
main
-