Class FunctionExpander.ChebyshevForest1
java.lang.Object
com.github.gbenroscience.math.numericalmethods.FunctionExpander.ChebyshevForest1
- Enclosing class:
FunctionExpander
- Author:
- GBEMIRO
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidvoidbuild(MethodHandle function, double a, double b) doublederivative(double x) To find the derivative at x, we find the specific segment containing x.doubleevaluate(double x) doubleThe global integral is simply the sum of the integrals of all segments.
-
Constructor Details
-
ChebyshevForest1
public ChebyshevForest1()
-
-
Method Details
-
build
- Throws:
Throwable
-
build
-
integrate
public double integrate()The global integral is simply the sum of the integrals of all segments. -
derivative
public double derivative(double x) To find the derivative at x, we find the specific segment containing x. -
evaluate
public double evaluate(double x)
-