Class BaseNFunction

java.lang.Object
com.github.gbenroscience.parser.MathExpression
com.github.gbenroscience.math.otherBaseParser.BaseNFunction
All Implemented Interfaces:
Savable, Solvable, Serializable

public class BaseNFunction extends MathExpression
Author:
JIBOYE Oluwagbemiro Olaoluwa
See Also:
  • Constructor Details

    • BaseNFunction

      public BaseNFunction(String input, int baseOfOperation)
      Parameters:
      input - The function to be evaluated. The general format contains variable and constant declarations for variables and constants that are not yet initialized,assignment expressions for those that have been initialized and then an expression to evaluate. e.g. var x =-12; var y =x+1/12; const x1,x2,x3=10; var z =sin(3x-1)+2.98cos(4x);cos(3x+12); The last expression is function to be evaluated and it is always without any equals sign and may or may not end with a semicolon.
      baseOfOperation - The number base that objects of this class will use in computations.
  • Method Details

    • setBaseOfOperation

      public void setBaseOfOperation(int baseOfOperation)
    • getBaseOfOperation

      public int getBaseOfOperation()
    • solve

      public String solve()
      Specified by:
      solve in interface Solvable
      Overrides:
      solve in class MathExpression
    • main

      public static void main(String[] args)