Uses of Class
com.github.gbenroscience.parser.Function
Packages that use Function
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Function in com.github.gbenroscience.math.differentialcalculus
Methods in com.github.gbenroscience.math.differentialcalculus that return Function -
Uses of Function in com.github.gbenroscience.math.numericalmethods
Methods in com.github.gbenroscience.math.numericalmethods that return FunctionModifier and TypeMethodDescriptionFunctionExpander.getFunction()NumericalDerivative.getFunction()NumericalIntegral.getFunction()RootFinder.getFunction()NumericalDerivative.Parser.parseDerivativeCommand(String expression) RootFinder.parseFunction(String expression) Method that processes the format that this software will recognize for user input of an integral expression.Methods in com.github.gbenroscience.math.numericalmethods with parameters of type FunctionModifier and TypeMethodDescriptionstatic doublestatic doublestatic doublestatic doublevoidFunctionExpander.setFunction(Function function) Changes the Function object dealt with by this class.voidIntegration.setFunction(Function intFunc) voidNumericalDerivative.setFunction(Function function) voidNumericalIntegral.setFunction(Function function) voidRootFinder.setFunction(Function function) static doubleIntegration.trapezium(Function intFunc, double lowerLimit, double upperLimit, double accuracy, int maxIntervals) static doubleConstructors in com.github.gbenroscience.math.numericalmethods with parameters of type FunctionModifierConstructorDescriptionFunctionExpander(double xLower, double xUpper, int degree, int precision, Function function) Objects of this class will employ this constructor in creating the polynomial of best fit for the input function between the given boundary values of x.Integration(Function intFunc) Integration(Function intFunc, double lowerLimit, double upperLimit) NumericalDerivative(Function function, double xPoint) RootFinder(Function function, double x1) -
Uses of Function in com.github.gbenroscience.parser
Methods in com.github.gbenroscience.parser that return FunctionMethods in com.github.gbenroscience.parser with parameters of type Function -
Uses of Function in com.github.gbenroscience.util
Fields in com.github.gbenroscience.util with type parameters of type FunctionMethods in com.github.gbenroscience.util that return FunctionModifier and TypeMethodDescriptionstatic FunctionAdds a Function object to this FunctionManager.static FunctionFunctionManager.getFunction(String fName) static FunctionAttempts to retrieve a Function object from a FunctionManager based on its name.Methods in com.github.gbenroscience.util that return types with arguments of type FunctionMethods in com.github.gbenroscience.util with parameters of type FunctionMethod parameters in com.github.gbenroscience.util with type arguments of type FunctionModifier and TypeMethodDescriptionstatic voidstatic void -
Uses of Function in com.github.gbenroscience.util.io
Method parameters in com.github.gbenroscience.util.io with type arguments of type FunctionModifier and TypeMethodDescriptionstatic voidFunctionsBackup.readFileLinesToMap(Map<String, Function> map, File fileToRead) This reads the lines of text in a file into aMap.static voidFunctionsBackup.writeMapItemsToFileLineByLine(Map<String, Function> map, File file) This writes items on a queue to a file.