Uses of Class
com.github.gbenroscience.parser.MathExpression
Packages that use MathExpression
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of MathExpression in com.github.gbenroscience.math.matrix.expressParser
Subclasses of MathExpression in com.github.gbenroscience.math.matrix.expressParserMethods in com.github.gbenroscience.math.matrix.expressParser with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic voidMatrixOperator.orderCompoundTokens(MathExpression function) -
Uses of MathExpression in com.github.gbenroscience.math.otherBaseParser
Subclasses of MathExpression in com.github.gbenroscience.math.otherBaseParser -
Uses of MathExpression in com.github.gbenroscience.parser
Subclasses of MathExpression in com.github.gbenroscience.parserMethods in com.github.gbenroscience.parser that return MathExpressionMethods in com.github.gbenroscience.parser with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic voidUnaryPreOperator.assignCompoundTokens(MathExpression function) voidFunction.setMathExpression(MathExpression mathExpression) voidNumber.validateNumber(MathExpression function) Constructors in com.github.gbenroscience.parser with parameters of type MathExpressionModifierConstructorDescriptionSet(MathExpression function, List<String> data) Creates a new Set object initialized with a set of data coming from a mathematical MathExpression. -
Uses of MathExpression in com.github.gbenroscience.util
Methods in com.github.gbenroscience.util that return MathExpressionModifier and TypeMethodDescriptionMathExpressionManager.createFunction(String expr) MathExpressionManager.getFunction(MathExpression function) MathExpressionManager.getFunctionAt(int index) MathExpressionManager.getFunctionByExpression(String expression) MathExpressionManager.getFunctionByScanner(ArrayList<String> scanner) MathExpressionManager.optimizeFunction(String name) Methods in com.github.gbenroscience.util that return types with arguments of type MathExpressionMethods in com.github.gbenroscience.util with parameters of type MathExpressionModifier and TypeMethodDescriptionstatic StringMathExpressionManager.analyzeSolution(MathExpression expr) booleanMathExpressionManager.contains(MathExpression func) MathExpressionManager.getFunction(MathExpression function) voidMathExpressionManager.storeFunction(MathExpression function) stores a MathExpression in objects of this class.Method parameters in com.github.gbenroscience.util with type arguments of type MathExpressionModifier and TypeMethodDescriptionvoidMathExpressionManager.setFunctions(ArrayList<MathExpression> functions)