Uses of Class
com.github.gbenroscience.parser.Variable
Packages that use Variable
Package
Description
Classes designed to parse a mathematical expression.
-
Uses of Variable in com.github.gbenroscience.math.graph
Methods in com.github.gbenroscience.math.graph that return VariableMethods in com.github.gbenroscience.math.graph with parameters of type VariableModifier and TypeMethodDescriptionvoidGrid.setHorizontalAxisLabel(Variable horizontalAxisLabel) voidGrid.setVerticalAxisLabel(Variable verticalAxisLabel) -
Uses of Variable in com.github.gbenroscience.parser
Fields in com.github.gbenroscience.parser declared as VariableModifier and TypeFieldDescriptionstatic VariableVariable.ansThe last answer variable used for flexibility on computational systems.static VariableVariable.estatic final VariableVariable.PIThe constant PIMethods in com.github.gbenroscience.parser that return VariableModifier and TypeMethodDescriptionFunction.getDependentVariable()Function.getIndependentVariable(String name) static VariableMethods in com.github.gbenroscience.parser that return types with arguments of type VariableMethods in com.github.gbenroscience.parser with parameters of type VariableMethod parameters in com.github.gbenroscience.parser with type arguments of type VariableModifier and TypeMethodDescriptionvoidFunction.setIndependentVariables(ArrayList<Variable> independentVariables) -
Uses of Variable in com.github.gbenroscience.util
Fields in com.github.gbenroscience.util with type parameters of type VariableMethods in com.github.gbenroscience.util that return VariableModifier and TypeMethodDescriptionVariableGenerator.generateVariable()static VariableVariableManager.getVariable(String vName) static VariableAttempts to retrieve a Variable object from a VariableManager based on its name.VariableManager.parseSingleCommand(String cmd) Parses a command that creates a single variable or changes its value.Methods in com.github.gbenroscience.util that return types with arguments of type VariableMethods in com.github.gbenroscience.util with parameters of type VariableModifier and TypeMethodDescriptionstatic voidIntroduces a Variablestatic voidIntroduces an array or variable-args list of VariableMethod parameters in com.github.gbenroscience.util with type arguments of type VariableModifier and TypeMethodDescriptionstatic voidVariableManager.load(Collection<Variable> variables) static voidstatic void -
Uses of Variable in com.github.gbenroscience.util.io
Method parameters in com.github.gbenroscience.util.io with type arguments of type VariableModifier and TypeMethodDescriptionstatic voidThis reads the lines of text in a file into aMap.static voidVariableBackup.readFileLinesToMap(Map<String, Variable> map, File fileToRead) This reads the lines of text in a file into aMap.static voidVariableBackup.writeMapItemsToFileLineByLine(Map<String, Variable> map, File file) This writes items on a queue to a file.