Interface MethodRegistry.MethodAction

All Known Implementing Classes:
Function
Enclosing class:
MethodRegistry

public static interface MethodRegistry.MethodAction
Author:
GBEMIRO
  • Method Details

    • calc

      Allows methods like diff(fn,args) to differentiate an expression using the MethodRegistry interface Is the intersection between methods and user-defined functions
      Parameters:
      nextResult -
      arity - The number of argument to read from the args array
      args - The args passed to the function
      Returns: