Interface MethodRegistry.MethodAction
- All Known Implementing Classes:
Function
- Enclosing class:
MethodRegistry
public static interface MethodRegistry.MethodAction
- Author:
- GBEMIRO
-
Method Summary
Modifier and TypeMethodDescriptioncalc(MathExpression.EvalResult nextResult, int arity, MathExpression.EvalResult[] args) Allows methods like diff(fn,args) to differentiate an expression using the MethodRegistry interface Is the intersection between methods and user-defined functions
-
Method Details
-
calc
MathExpression.EvalResult calc(MathExpression.EvalResult nextResult, int arity, MathExpression.EvalResult[] args) Allows methods like diff(fn,args) to differentiate an expression using the MethodRegistry interface Is the intersection between methods and user-defined functions- Parameters:
nextResult-arity- The number of argument to read from the args arrayargs- The args passed to the function- Returns:
-