Package com.github.gbenroscience.parser
package com.github.gbenroscience.parser
Classes designed to parse a mathematical expression.
- Author:
- JIBOYE, Oluwagbemiro Olaoluwa
-
ClassDescriptionRemoves excess/redundant brackets from a tokenized mathematical expression **in-place**.Objects of this class take a data-set and simplify/reduce its complexity so that class MathExpression can easily work with it.Examples are sort function, mode function and other methods that will return a list of numbers after acting on a number or a list of numbersThis class is NOT thread-safe.MathExpression.Pair<K,
V> Manages the mapping of variable names to frame slots.Optimized Java class to compute the depth (height) of the abstract syntax tree (AST) for a mathematical expression.Deals with number returning statistical operators e.g sum,avg,mode e.t.c and log and antilog to any base operatorsClass that provides utility methods for carrying out statistical analysis on a data set consisting of real numbers.Defines the allowed return typesModels a post-operand Operator object e.g the !, inverse, square, cube operatorsModels a post-operand Operator object e.g the trigonometric,logarithmic,exponential e.t.c.