Class KernelInterceptException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.github.gbenroscience.parser.turbo.tools.exceptions.KernelInterceptException
- All Implemented Interfaces:
Serializable
- Author:
- GBEMIRO An internal control-flow signal thrown during AST compilation to indicate that a function should be routed to a FlatMatrix kernel instead of being compiled into a standard lane-by-lane vector tree.
- See Also:
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionintMethods inherited from class java.lang.Throwable
addSuppressed, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
KernelInterceptException
-
-
Method Details
-
getKernelName
-
getExpectedArity
public int getExpectedArity() -
fillInStackTrace
- Overrides:
fillInStackTracein classThrowable
-