-
-
Package logic
-
Class logic.CalcLogic extends java.lang.Object implements Serializable
-
Serialized Fields
-
baseMode
BASE_MODE baseMode
-
commandHistory
java.util.ArrayList<java.lang.String> commandHistory
Stores the commands used on the CommandLineActivity
-
drgMode
DRG_MODE drgMode
-
formMan
FormulaeManager formMan
-
funcMan
MathExpressionManager funcMan
-
histMan
HistoryManager histMan
-
justEvaluated
boolean justEvaluated
When true, the calculator is in a state wherein the last action it performed
was the evaluation of an expression.
-
manager
OperatingSystem manager
-
mode
Mode mode
-
powerMode
POWER_MODE powerMode
-
running
boolean running
-
settings
Settings settings
-
trigMode
TRIG_MODE trigMode
-
useMode
USE_MODE useMode
-
vibrateOn
boolean vibrateOn
-
Package math.matrix.expressParser
-
Package math.otherBaseParser
-
Package parser
-
Class parser.Function extends java.lang.Object implements Serializable
-
Serialized Fields
-
dependentVariable
Variable dependentVariable
The dependent variable
-
independentVariables
java.util.ArrayList<Variable> independentVariables
The independent variables.
-
mathExpression
MathExpression mathExpression
If the object is an algebraic expression, its details are stored here.
The math expression on the RHS.
-
matrix
Matrix matrix
If the object is a
Matrix its data is stored here.
-
type
int type
The type of the function
-
Class parser.MathExpression extends java.lang.Object implements Serializable
-
Serialized Fields
-
bracket
Bracket[] bracket
-
correctFunction
boolean correctFunction
-
DRG
int DRG
-
expression
java.lang.String expression
The expression to evaluate.
-
hasFunctionOrVariableInitStatement
boolean hasFunctionOrVariableInitStatement
Set this attribute to true, if and only if the input into this system is
meant to initialize or change the value of variable data alone and is not
calculating a standalone math expression. For example, var a =2;var
b=3;var c=cos(a-b);f(x)=3*x^2; d=3cos(c);
where c has been declared before!
-
hasListReturningOperators
boolean hasListReturningOperators
-
hasLogicOperators
boolean hasLogicOperators
-
hasMulOrDivOperators
boolean hasMulOrDivOperators
-
hasNumberReturningStatsOperators
boolean hasNumberReturningStatsOperators
-
hasPermOrCombOperators
boolean hasPermOrCombOperators
-
hasPlusOrMinusOperators
boolean hasPlusOrMinusOperators
-
hasPostNumberOperators
boolean hasPostNumberOperators
-
hasPowerOperators
boolean hasPowerOperators
-
hasPreNumberOperators
boolean hasPreNumberOperators
-
hasRemainderOperators
boolean hasRemainderOperators
-
noOfListReturningOperators
int noOfListReturningOperators
-
optimizable
boolean optimizable
-
parser_Result
Parser_Result parser_Result
-
returnObjectName
java.lang.String returnObjectName
Sometimes, after evaluation the evaluation list which is a local
variable, is reduced to a function name(or other object as time goes on)
instead of a number of other list. The parser unfortunately will not
return this variable, but instead returns the data which it refers
to..e.g a
Matrix function or other. But we atimes need that
function name...So we cache this value here.
-
returnType
TYPE returnType
The type of output returned by the parser.
-
scanner
java.util.ArrayList<java.lang.String> scanner
-
utility
java.lang.StringBuilder utility
Utility attribute used throughout the class for string appending
operations.
-
variableManager
VariableManager variableManager
The VariableManager object that allows an object of this class to
remember its variables.
-
whitespaceremover
java.util.ArrayList<java.lang.String> whitespaceremover
-
-
-
Package util
-
-
Class util.Settings extends java.lang.Object implements Serializable
-
Package util.help
-
Class util.help.Topic extends java.lang.Object implements Serializable
-
Serialized Fields
-
content
java.lang.String content
-
title
java.lang.String title
-